# coding: utf-8

"""
    Moodle Webservice API

    Auto-generated OpenAPI spec for Moodle's Webservice API.

    The version of the OpenAPI document: 5.0.3 (Build: 20251006)
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

from poodle_async_full.configuration import settings

class CoreSearchGetResultsParametersFilters(BaseModel):
    """
    filters to apply
    """ # noqa: E501
    areaids: Optional[List[Optional[StrictStr]]] = Field(default=None, description="restrict results to these areas")
    cat: Optional[StrictStr] = Field(default='', description="category to filter areas")
    contextids: Optional[List[Optional[StrictInt]]] = Field(default=None, description="restrict results to these contexts")
    courseids: Optional[List[Optional[StrictInt]]] = Field(default=None, description="restrict results to these courses")
    groupids: Optional[List[Optional[StrictInt]]] = Field(default=None, description="restrict results to these groups")
    mycoursesonly: Optional[StrictBool] = Field(default=False, description="only results from my courses")
    order: Optional[StrictStr] = Field(default='', description="how to order")
    timeend: Optional[StrictInt] = Field(default=0, description="docs modified before this date")
    timestart: Optional[StrictInt] = Field(default=0, description="docs modified after this date")
    title: Optional[StrictStr] = Field(default=None, description="result title")
    userids: Optional[List[Optional[StrictInt]]] = Field(default=None, description="restrict results to these users")
    __properties: ClassVar[List[str]] = ["areaids", "cat", "contextids", "courseids", "groupids", "mycoursesonly", "order", "timeend", "timestart", "title", "userids"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CoreSearchGetResultsParametersFilters from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if cat (nullable) is None
        # and model_fields_set contains the field
        if self.cat is None and "cat" in self.model_fields_set:
            _dict['cat'] = None

        # set to None if mycoursesonly (nullable) is None
        # and model_fields_set contains the field
        if self.mycoursesonly is None and "mycoursesonly" in self.model_fields_set:
            _dict['mycoursesonly'] = None

        # set to None if order (nullable) is None
        # and model_fields_set contains the field
        if self.order is None and "order" in self.model_fields_set:
            _dict['order'] = None

        # set to None if timeend (nullable) is None
        # and model_fields_set contains the field
        if self.timeend is None and "timeend" in self.model_fields_set:
            _dict['timeend'] = None

        # set to None if timestart (nullable) is None
        # and model_fields_set contains the field
        if self.timestart is None and "timestart" in self.model_fields_set:
            _dict['timestart'] = None

        # set to None if title (nullable) is None
        # and model_fields_set contains the field
        if self.title is None and "title" in self.model_fields_set:
            _dict['title'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CoreSearchGetResultsParametersFilters from a dict"""
        if obj is None:
            return None

        relaxed = settings.relaxe_all_models or "CoreSearchGetResultsParametersFilters" in settings.relaxed_models

        if not isinstance(obj, dict):
            return cls.model_construct(**obj) if relaxed else cls.model_validate(obj)

        data = {
            "areaids": obj.get("areaids"),
            "cat": obj.get("cat") if obj.get("cat") is not None else '',
            "contextids": obj.get("contextids"),
            "courseids": obj.get("courseids"),
            "groupids": obj.get("groupids"),
            "mycoursesonly": obj.get("mycoursesonly") if obj.get("mycoursesonly") is not None else False,
            "order": obj.get("order") if obj.get("order") is not None else '',
            "timeend": obj.get("timeend") if obj.get("timeend") is not None else 0,
            "timestart": obj.get("timestart") if obj.get("timestart") is not None else 0,
            "title": obj.get("title"),
            "userids": obj.get("userids")
        }
        _obj = cls.model_construct(**data) if relaxed else cls.model_validate(data)
        return _obj





# coding: utf-8

"""
    Moodle Webservice API

    Auto-generated OpenAPI spec for Moodle's Webservice API.

    The version of the OpenAPI document: 5.0.3 (Build: 20251006)
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from poodle_async_full.models.core_block_get_course_blocks_response_blocks_inner_contents_files_inner import CoreBlockGetCourseBlocksResponseBlocksInnerContentsFilesInner
from poodle_async_full.models.core_blog_get_entries_response_entries_inner_tags_inner import CoreBlogGetEntriesResponseEntriesInnerTagsInner
from typing import Optional, Set
from typing_extensions import Self

from poodle_async_full.configuration import settings

class ModGlossaryGetEntriesByAuthorIdResponseEntriesInner(BaseModel):
    """
    ModGlossaryGetEntriesByAuthorIdResponseEntriesInner
    """ # noqa: E501
    approved: Optional[StrictBool] = Field(description="Whether the entry was approved")
    attachment: Optional[StrictBool] = Field(description="Whether or not the entry has attachments")
    attachments: Optional[List[CoreBlockGetCourseBlocksResponseBlocksInnerContentsFilesInner]] = Field(default=None, description="attachments")
    casesensitive: Optional[StrictBool] = Field(description="When true, the matching is case sensitive")
    concept: Optional[StrictStr] = Field(description="The concept")
    definition: Optional[StrictStr] = Field(description="The definition")
    definitionformat: Optional[StrictInt] = Field(description="definition format (1 = HTML, 0 = MOODLE, 2 = PLAIN, or 4 = MARKDOWN)")
    definitioninlinefiles: Optional[List[CoreBlockGetCourseBlocksResponseBlocksInnerContentsFilesInner]] = Field(default=None, description="entry definition inline files")
    definitiontrust: Optional[StrictBool] = Field(description="The definition trust flag")
    fullmatch: Optional[StrictBool] = Field(description="When true, the matching is done on full words only")
    glossaryid: Optional[StrictInt] = Field(description="The glossary ID")
    id: Optional[StrictInt] = Field(description="The entry ID")
    sourceglossaryid: Optional[StrictInt] = Field(description="The source glossary ID")
    tags: Optional[List[CoreBlogGetEntriesResponseEntriesInnerTagsInner]] = Field(default=None, description="Tags")
    teacherentry: Optional[StrictBool] = Field(description="The entry was created by a teacher, or equivalent.")
    timecreated: Optional[StrictInt] = Field(description="Time created")
    timemodified: Optional[StrictInt] = Field(description="Time modified")
    usedynalink: Optional[StrictBool] = Field(description="Whether the concept should be automatically linked")
    userfullname: Optional[StrictStr] = Field(description="Author full name")
    userid: Optional[StrictInt] = Field(description="Author ID")
    userpictureurl: Optional[StrictStr] = Field(description="Author picture")
    __properties: ClassVar[List[str]] = ["approved", "attachment", "attachments", "casesensitive", "concept", "definition", "definitionformat", "definitioninlinefiles", "definitiontrust", "fullmatch", "glossaryid", "id", "sourceglossaryid", "tags", "teacherentry", "timecreated", "timemodified", "usedynalink", "userfullname", "userid", "userpictureurl"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ModGlossaryGetEntriesByAuthorIdResponseEntriesInner from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in attachments (list)
        _items = []
        if self.attachments:
            for _item_attachments in self.attachments:
                if _item_attachments:
                    _items.append(_item_attachments.to_dict())
            _dict['attachments'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in definitioninlinefiles (list)
        _items = []
        if self.definitioninlinefiles:
            for _item_definitioninlinefiles in self.definitioninlinefiles:
                if _item_definitioninlinefiles:
                    _items.append(_item_definitioninlinefiles.to_dict())
            _dict['definitioninlinefiles'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in tags (list)
        _items = []
        if self.tags:
            for _item_tags in self.tags:
                if _item_tags:
                    _items.append(_item_tags.to_dict())
            _dict['tags'] = _items
        # set to None if approved (nullable) is None
        # and model_fields_set contains the field
        if self.approved is None and "approved" in self.model_fields_set:
            _dict['approved'] = None

        # set to None if attachment (nullable) is None
        # and model_fields_set contains the field
        if self.attachment is None and "attachment" in self.model_fields_set:
            _dict['attachment'] = None

        # set to None if casesensitive (nullable) is None
        # and model_fields_set contains the field
        if self.casesensitive is None and "casesensitive" in self.model_fields_set:
            _dict['casesensitive'] = None

        # set to None if concept (nullable) is None
        # and model_fields_set contains the field
        if self.concept is None and "concept" in self.model_fields_set:
            _dict['concept'] = None

        # set to None if definition (nullable) is None
        # and model_fields_set contains the field
        if self.definition is None and "definition" in self.model_fields_set:
            _dict['definition'] = None

        # set to None if definitionformat (nullable) is None
        # and model_fields_set contains the field
        if self.definitionformat is None and "definitionformat" in self.model_fields_set:
            _dict['definitionformat'] = None

        # set to None if definitiontrust (nullable) is None
        # and model_fields_set contains the field
        if self.definitiontrust is None and "definitiontrust" in self.model_fields_set:
            _dict['definitiontrust'] = None

        # set to None if fullmatch (nullable) is None
        # and model_fields_set contains the field
        if self.fullmatch is None and "fullmatch" in self.model_fields_set:
            _dict['fullmatch'] = None

        # set to None if glossaryid (nullable) is None
        # and model_fields_set contains the field
        if self.glossaryid is None and "glossaryid" in self.model_fields_set:
            _dict['glossaryid'] = None

        # set to None if id (nullable) is None
        # and model_fields_set contains the field
        if self.id is None and "id" in self.model_fields_set:
            _dict['id'] = None

        # set to None if sourceglossaryid (nullable) is None
        # and model_fields_set contains the field
        if self.sourceglossaryid is None and "sourceglossaryid" in self.model_fields_set:
            _dict['sourceglossaryid'] = None

        # set to None if teacherentry (nullable) is None
        # and model_fields_set contains the field
        if self.teacherentry is None and "teacherentry" in self.model_fields_set:
            _dict['teacherentry'] = None

        # set to None if timecreated (nullable) is None
        # and model_fields_set contains the field
        if self.timecreated is None and "timecreated" in self.model_fields_set:
            _dict['timecreated'] = None

        # set to None if timemodified (nullable) is None
        # and model_fields_set contains the field
        if self.timemodified is None and "timemodified" in self.model_fields_set:
            _dict['timemodified'] = None

        # set to None if usedynalink (nullable) is None
        # and model_fields_set contains the field
        if self.usedynalink is None and "usedynalink" in self.model_fields_set:
            _dict['usedynalink'] = None

        # set to None if userfullname (nullable) is None
        # and model_fields_set contains the field
        if self.userfullname is None and "userfullname" in self.model_fields_set:
            _dict['userfullname'] = None

        # set to None if userid (nullable) is None
        # and model_fields_set contains the field
        if self.userid is None and "userid" in self.model_fields_set:
            _dict['userid'] = None

        # set to None if userpictureurl (nullable) is None
        # and model_fields_set contains the field
        if self.userpictureurl is None and "userpictureurl" in self.model_fields_set:
            _dict['userpictureurl'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ModGlossaryGetEntriesByAuthorIdResponseEntriesInner from a dict"""
        if obj is None:
            return None

        relaxed = settings.relaxe_all_models or "ModGlossaryGetEntriesByAuthorIdResponseEntriesInner" in settings.relaxed_models

        if not isinstance(obj, dict):
            return cls.model_construct(**obj) if relaxed else cls.model_validate(obj)

        data = {
            "approved": obj.get("approved"),
            "attachment": obj.get("attachment"),
            "attachments": [CoreBlockGetCourseBlocksResponseBlocksInnerContentsFilesInner.from_dict(_item) for _item in obj["attachments"]] if obj.get("attachments") is not None else None,
            "casesensitive": obj.get("casesensitive"),
            "concept": obj.get("concept"),
            "definition": obj.get("definition"),
            "definitionformat": obj.get("definitionformat"),
            "definitioninlinefiles": [CoreBlockGetCourseBlocksResponseBlocksInnerContentsFilesInner.from_dict(_item) for _item in obj["definitioninlinefiles"]] if obj.get("definitioninlinefiles") is not None else None,
            "definitiontrust": obj.get("definitiontrust"),
            "fullmatch": obj.get("fullmatch"),
            "glossaryid": obj.get("glossaryid"),
            "id": obj.get("id"),
            "sourceglossaryid": obj.get("sourceglossaryid"),
            "tags": [CoreBlogGetEntriesResponseEntriesInnerTagsInner.from_dict(_item) for _item in obj["tags"]] if obj.get("tags") is not None else None,
            "teacherentry": obj.get("teacherentry"),
            "timecreated": obj.get("timecreated"),
            "timemodified": obj.get("timemodified"),
            "usedynalink": obj.get("usedynalink"),
            "userfullname": obj.get("userfullname"),
            "userid": obj.get("userid"),
            "userpictureurl": obj.get("userpictureurl")
        }
        _obj = cls.model_construct(**data) if relaxed else cls.model_validate(data)
        return _obj





# coding: utf-8

"""
    Moodle Webservice API

    Auto-generated OpenAPI spec for Moodle's Webservice API.

    The version of the OpenAPI document: 5.0.3 (Build: 20251006)
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from poodle_async_full.models.core_block_get_course_blocks_response_blocks_inner_contents_files_inner import CoreBlockGetCourseBlocksResponseBlocksInnerContentsFilesInner
from poodle_async_full.models.core_cohort_get_cohorts_response_inner_customfields_inner import CoreCohortGetCohortsResponseInnerCustomfieldsInner
from poodle_async_full.models.core_course_get_courses_by_field_response_courses_inner_contacts_inner import CoreCourseGetCoursesByFieldResponseCoursesInnerContactsInner
from typing import Optional, Set
from typing_extensions import Self

from poodle_async_full.configuration import settings

class CoreCourseSearchCoursesResponseCoursesInner(BaseModel):
    """
    CoreCourseSearchCoursesResponseCoursesInner
    """ # noqa: E501
    categoryid: Optional[StrictInt] = Field(description="category id")
    categoryname: Optional[StrictStr] = Field(description="category name")
    contacts: List[CoreCourseGetCoursesByFieldResponseCoursesInnerContactsInner] = Field(description="contact users")
    courseimage: Optional[StrictStr] = Field(default=None, description="Course image")
    customfields: Optional[List[CoreCohortGetCohortsResponseInnerCustomfieldsInner]] = Field(default=None, description="Custom fields")
    displayname: Optional[StrictStr] = Field(description="course display name")
    enrollmentmethods: List[Optional[StrictStr]] = Field(description="enrollment methods list")
    fullname: Optional[StrictStr] = Field(description="course full name")
    id: Optional[StrictInt] = Field(description="course id")
    overviewfiles: List[CoreBlockGetCourseBlocksResponseBlocksInnerContentsFilesInner] = Field(description="additional overview files attached to this course")
    shortname: Optional[StrictStr] = Field(description="course short name")
    showactivitydates: Optional[StrictBool] = Field(description="Whether the activity dates are shown or not")
    showcompletionconditions: Optional[StrictBool] = Field(description="Whether the activity completion conditions are shown or not")
    sortorder: Optional[StrictInt] = Field(default=None, description="Sort order in the category")
    summary: Optional[StrictStr] = Field(description="summary")
    summaryfiles: Optional[List[CoreBlockGetCourseBlocksResponseBlocksInnerContentsFilesInner]] = Field(default=None, description="summary files in the summary field")
    summaryformat: Optional[StrictInt] = Field(description="summary format (1 = HTML, 0 = MOODLE, 2 = PLAIN, or 4 = MARKDOWN)")
    __properties: ClassVar[List[str]] = ["categoryid", "categoryname", "contacts", "courseimage", "customfields", "displayname", "enrollmentmethods", "fullname", "id", "overviewfiles", "shortname", "showactivitydates", "showcompletionconditions", "sortorder", "summary", "summaryfiles", "summaryformat"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CoreCourseSearchCoursesResponseCoursesInner from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in contacts (list)
        _items = []
        if self.contacts:
            for _item_contacts in self.contacts:
                if _item_contacts:
                    _items.append(_item_contacts.to_dict())
            _dict['contacts'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in customfields (list)
        _items = []
        if self.customfields:
            for _item_customfields in self.customfields:
                if _item_customfields:
                    _items.append(_item_customfields.to_dict())
            _dict['customfields'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in overviewfiles (list)
        _items = []
        if self.overviewfiles:
            for _item_overviewfiles in self.overviewfiles:
                if _item_overviewfiles:
                    _items.append(_item_overviewfiles.to_dict())
            _dict['overviewfiles'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in summaryfiles (list)
        _items = []
        if self.summaryfiles:
            for _item_summaryfiles in self.summaryfiles:
                if _item_summaryfiles:
                    _items.append(_item_summaryfiles.to_dict())
            _dict['summaryfiles'] = _items
        # set to None if categoryid (nullable) is None
        # and model_fields_set contains the field
        if self.categoryid is None and "categoryid" in self.model_fields_set:
            _dict['categoryid'] = None

        # set to None if categoryname (nullable) is None
        # and model_fields_set contains the field
        if self.categoryname is None and "categoryname" in self.model_fields_set:
            _dict['categoryname'] = None

        # set to None if courseimage (nullable) is None
        # and model_fields_set contains the field
        if self.courseimage is None and "courseimage" in self.model_fields_set:
            _dict['courseimage'] = None

        # set to None if displayname (nullable) is None
        # and model_fields_set contains the field
        if self.displayname is None and "displayname" in self.model_fields_set:
            _dict['displayname'] = None

        # set to None if fullname (nullable) is None
        # and model_fields_set contains the field
        if self.fullname is None and "fullname" in self.model_fields_set:
            _dict['fullname'] = None

        # set to None if id (nullable) is None
        # and model_fields_set contains the field
        if self.id is None and "id" in self.model_fields_set:
            _dict['id'] = None

        # set to None if shortname (nullable) is None
        # and model_fields_set contains the field
        if self.shortname is None and "shortname" in self.model_fields_set:
            _dict['shortname'] = None

        # set to None if showactivitydates (nullable) is None
        # and model_fields_set contains the field
        if self.showactivitydates is None and "showactivitydates" in self.model_fields_set:
            _dict['showactivitydates'] = None

        # set to None if showcompletionconditions (nullable) is None
        # and model_fields_set contains the field
        if self.showcompletionconditions is None and "showcompletionconditions" in self.model_fields_set:
            _dict['showcompletionconditions'] = None

        # set to None if sortorder (nullable) is None
        # and model_fields_set contains the field
        if self.sortorder is None and "sortorder" in self.model_fields_set:
            _dict['sortorder'] = None

        # set to None if summary (nullable) is None
        # and model_fields_set contains the field
        if self.summary is None and "summary" in self.model_fields_set:
            _dict['summary'] = None

        # set to None if summaryformat (nullable) is None
        # and model_fields_set contains the field
        if self.summaryformat is None and "summaryformat" in self.model_fields_set:
            _dict['summaryformat'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CoreCourseSearchCoursesResponseCoursesInner from a dict"""
        if obj is None:
            return None

        relaxed = settings.relaxe_all_models or "CoreCourseSearchCoursesResponseCoursesInner" in settings.relaxed_models

        if not isinstance(obj, dict):
            return cls.model_construct(**obj) if relaxed else cls.model_validate(obj)

        data = {
            "categoryid": obj.get("categoryid"),
            "categoryname": obj.get("categoryname"),
            "contacts": [CoreCourseGetCoursesByFieldResponseCoursesInnerContactsInner.from_dict(_item) for _item in obj["contacts"]] if obj.get("contacts") is not None else None,
            "courseimage": obj.get("courseimage"),
            "customfields": [CoreCohortGetCohortsResponseInnerCustomfieldsInner.from_dict(_item) for _item in obj["customfields"]] if obj.get("customfields") is not None else None,
            "displayname": obj.get("displayname"),
            "enrollmentmethods": obj.get("enrollmentmethods"),
            "fullname": obj.get("fullname"),
            "id": obj.get("id"),
            "overviewfiles": [CoreBlockGetCourseBlocksResponseBlocksInnerContentsFilesInner.from_dict(_item) for _item in obj["overviewfiles"]] if obj.get("overviewfiles") is not None else None,
            "shortname": obj.get("shortname"),
            "showactivitydates": obj.get("showactivitydates"),
            "showcompletionconditions": obj.get("showcompletionconditions"),
            "sortorder": obj.get("sortorder"),
            "summary": obj.get("summary"),
            "summaryfiles": [CoreBlockGetCourseBlocksResponseBlocksInnerContentsFilesInner.from_dict(_item) for _item in obj["summaryfiles"]] if obj.get("summaryfiles") is not None else None,
            "summaryformat": obj.get("summaryformat")
        }
        _obj = cls.model_construct(**data) if relaxed else cls.model_validate(data)
        return _obj





# coding: utf-8

"""
    Moodle Webservice API

    Auto-generated OpenAPI spec for Moodle's Webservice API.

    The version of the OpenAPI document: 5.0.3 (Build: 20251006)
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from poodle_async_full.models.core_competency_create_plan_response_commentarea import CoreCompetencyCreatePlanResponseCommentarea
from poodle_async_full.models.core_competency_create_plan_response_reviewer import CoreCompetencyCreatePlanResponseReviewer
from poodle_async_full.models.core_competency_create_plan_response_template import CoreCompetencyCreatePlanResponseTemplate
from typing import Optional, Set
from typing_extensions import Self

from poodle_async_full.configuration import settings

class CoreCompetencyUpdatePlanResponse(BaseModel):
    """
    CoreCompetencyUpdatePlanResponse
    """ # noqa: E501
    canbeedited: StrictBool = Field(description="canbeedited")
    canmanage: StrictBool = Field(description="canmanage")
    canrequestreview: StrictBool = Field(description="canrequestreview")
    canreview: StrictBool = Field(description="canreview")
    commentarea: CoreCompetencyCreatePlanResponseCommentarea
    description: StrictStr = Field(description="description")
    descriptionformat: Optional[StrictInt] = Field(default=1, description="description format (1 = HTML, 0 = MOODLE, 2 = PLAIN, or 4 = MARKDOWN)")
    duedate: StrictInt = Field(description="duedate")
    duedateformatted: StrictStr = Field(description="duedateformatted")
    id: StrictInt = Field(description="id")
    isactive: StrictBool = Field(description="isactive")
    isapproveallowed: StrictBool = Field(description="isapproveallowed")
    isbasedontemplate: StrictBool = Field(description="isbasedontemplate")
    iscancelreviewrequestallowed: StrictBool = Field(description="iscancelreviewrequestallowed")
    iscompleteallowed: StrictBool = Field(description="iscompleteallowed")
    iscompleted: StrictBool = Field(description="iscompleted")
    isdraft: StrictBool = Field(description="isdraft")
    isinreview: StrictBool = Field(description="isinreview")
    isreopenallowed: StrictBool = Field(description="isreopenallowed")
    isrequestreviewallowed: StrictBool = Field(description="isrequestreviewallowed")
    isstartreviewallowed: StrictBool = Field(description="isstartreviewallowed")
    isstopreviewallowed: StrictBool = Field(description="isstopreviewallowed")
    isunapproveallowed: StrictBool = Field(description="isunapproveallowed")
    isunlinkallowed: StrictBool = Field(description="isunlinkallowed")
    iswaitingforreview: StrictBool = Field(description="iswaitingforreview")
    name: StrictStr = Field(description="name")
    origtemplateid: Optional[StrictInt] = Field(description="origtemplateid")
    reviewer: Optional[CoreCompetencyCreatePlanResponseReviewer] = None
    reviewerid: Optional[StrictInt] = Field(description="reviewerid")
    status: StrictInt = Field(description="status")
    statusname: StrictStr = Field(description="statusname")
    template: Optional[CoreCompetencyCreatePlanResponseTemplate] = None
    templateid: Optional[StrictInt] = Field(description="templateid")
    timecreated: StrictInt = Field(description="timecreated")
    timemodified: StrictInt = Field(description="timemodified")
    url: StrictStr = Field(description="url")
    userid: StrictInt = Field(description="userid")
    usermodified: StrictInt = Field(description="usermodified")
    __properties: ClassVar[List[str]] = ["canbeedited", "canmanage", "canrequestreview", "canreview", "commentarea", "description", "descriptionformat", "duedate", "duedateformatted", "id", "isactive", "isapproveallowed", "isbasedontemplate", "iscancelreviewrequestallowed", "iscompleteallowed", "iscompleted", "isdraft", "isinreview", "isreopenallowed", "isrequestreviewallowed", "isstartreviewallowed", "isstopreviewallowed", "isunapproveallowed", "isunlinkallowed", "iswaitingforreview", "name", "origtemplateid", "reviewer", "reviewerid", "status", "statusname", "template", "templateid", "timecreated", "timemodified", "url", "userid", "usermodified"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CoreCompetencyUpdatePlanResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of commentarea
        if self.commentarea:
            _dict['commentarea'] = self.commentarea.to_dict()
        # override the default output from pydantic by calling `to_dict()` of reviewer
        if self.reviewer:
            _dict['reviewer'] = self.reviewer.to_dict()
        # override the default output from pydantic by calling `to_dict()` of template
        if self.template:
            _dict['template'] = self.template.to_dict()
        # set to None if descriptionformat (nullable) is None
        # and model_fields_set contains the field
        if self.descriptionformat is None and "descriptionformat" in self.model_fields_set:
            _dict['descriptionformat'] = None

        # set to None if origtemplateid (nullable) is None
        # and model_fields_set contains the field
        if self.origtemplateid is None and "origtemplateid" in self.model_fields_set:
            _dict['origtemplateid'] = None

        # set to None if reviewerid (nullable) is None
        # and model_fields_set contains the field
        if self.reviewerid is None and "reviewerid" in self.model_fields_set:
            _dict['reviewerid'] = None

        # set to None if templateid (nullable) is None
        # and model_fields_set contains the field
        if self.templateid is None and "templateid" in self.model_fields_set:
            _dict['templateid'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CoreCompetencyUpdatePlanResponse from a dict"""
        if obj is None:
            return None

        relaxed = settings.relaxe_all_models or "CoreCompetencyUpdatePlanResponse" in settings.relaxed_models

        if not isinstance(obj, dict):
            return cls.model_construct(**obj) if relaxed else cls.model_validate(obj)

        data = {
            "canbeedited": obj.get("canbeedited") if obj.get("canbeedited") is not None else False,
            "canmanage": obj.get("canmanage") if obj.get("canmanage") is not None else False,
            "canrequestreview": obj.get("canrequestreview") if obj.get("canrequestreview") is not None else False,
            "canreview": obj.get("canreview") if obj.get("canreview") is not None else False,
            "commentarea": CoreCompetencyCreatePlanResponseCommentarea.from_dict(obj["commentarea"]) if obj.get("commentarea") is not None else None,
            "description": obj.get("description") if obj.get("description") is not None else '',
            "descriptionformat": obj.get("descriptionformat") if obj.get("descriptionformat") is not None else 1,
            "duedate": obj.get("duedate") if obj.get("duedate") is not None else 0,
            "duedateformatted": obj.get("duedateformatted") if obj.get("duedateformatted") is not None else '',
            "id": obj.get("id") if obj.get("id") is not None else 0,
            "isactive": obj.get("isactive") if obj.get("isactive") is not None else False,
            "isapproveallowed": obj.get("isapproveallowed") if obj.get("isapproveallowed") is not None else False,
            "isbasedontemplate": obj.get("isbasedontemplate") if obj.get("isbasedontemplate") is not None else False,
            "iscancelreviewrequestallowed": obj.get("iscancelreviewrequestallowed") if obj.get("iscancelreviewrequestallowed") is not None else False,
            "iscompleteallowed": obj.get("iscompleteallowed") if obj.get("iscompleteallowed") is not None else False,
            "iscompleted": obj.get("iscompleted") if obj.get("iscompleted") is not None else False,
            "isdraft": obj.get("isdraft") if obj.get("isdraft") is not None else False,
            "isinreview": obj.get("isinreview") if obj.get("isinreview") is not None else False,
            "isreopenallowed": obj.get("isreopenallowed") if obj.get("isreopenallowed") is not None else False,
            "isrequestreviewallowed": obj.get("isrequestreviewallowed") if obj.get("isrequestreviewallowed") is not None else False,
            "isstartreviewallowed": obj.get("isstartreviewallowed") if obj.get("isstartreviewallowed") is not None else False,
            "isstopreviewallowed": obj.get("isstopreviewallowed") if obj.get("isstopreviewallowed") is not None else False,
            "isunapproveallowed": obj.get("isunapproveallowed") if obj.get("isunapproveallowed") is not None else False,
            "isunlinkallowed": obj.get("isunlinkallowed") if obj.get("isunlinkallowed") is not None else False,
            "iswaitingforreview": obj.get("iswaitingforreview") if obj.get("iswaitingforreview") is not None else False,
            "name": obj.get("name") if obj.get("name") is not None else '',
            "origtemplateid": obj.get("origtemplateid"),
            "reviewer": CoreCompetencyCreatePlanResponseReviewer.from_dict(obj["reviewer"]) if obj.get("reviewer") is not None else None,
            "reviewerid": obj.get("reviewerid"),
            "status": obj.get("status") if obj.get("status") is not None else 0,
            "statusname": obj.get("statusname") if obj.get("statusname") is not None else '',
            "template": CoreCompetencyCreatePlanResponseTemplate.from_dict(obj["template"]) if obj.get("template") is not None else None,
            "templateid": obj.get("templateid"),
            "timecreated": obj.get("timecreated") if obj.get("timecreated") is not None else 0,
            "timemodified": obj.get("timemodified") if obj.get("timemodified") is not None else 0,
            "url": obj.get("url") if obj.get("url") is not None else '',
            "userid": obj.get("userid") if obj.get("userid") is not None else 0,
            "usermodified": obj.get("usermodified") if obj.get("usermodified") is not None else 0
        }
        _obj = cls.model_construct(**data) if relaxed else cls.model_validate(data)
        return _obj





# coding: utf-8

"""
    Moodle Webservice API

    Auto-generated OpenAPI spec for Moodle's Webservice API.

    The version of the OpenAPI document: 5.0.3 (Build: 20251006)
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

from poodle_async_full.configuration import settings

class CoreCalendarCreateCalendarEventsResponseEventsInner(BaseModel):
    """
    event
    """ # noqa: E501
    courseid: Optional[StrictInt] = Field(description="course id")
    description: Optional[StrictStr] = Field(default=None, description="Description")
    eventtype: Optional[StrictStr] = Field(description="Event type")
    format: Optional[StrictInt] = Field(description="description format (1 = HTML, 0 = MOODLE, 2 = PLAIN, or 4 = MARKDOWN)")
    groupid: Optional[StrictInt] = Field(description="group id")
    id: Optional[StrictInt] = Field(description="event id")
    instance: Optional[StrictInt] = Field(description="instance id")
    modulename: Optional[StrictStr] = Field(default=None, description="module name")
    name: Optional[StrictStr] = Field(description="event name")
    repeatid: Optional[StrictInt] = Field(default=None, description="repeat id")
    sequence: Optional[StrictInt] = Field(description="sequence")
    subscriptionid: Optional[StrictInt] = Field(default=None, description="Subscription id")
    timeduration: Optional[StrictInt] = Field(description="time duration")
    timemodified: Optional[StrictInt] = Field(description="time modified")
    timestart: Optional[StrictInt] = Field(description="timestart")
    userid: Optional[StrictInt] = Field(description="user id")
    uuid: Optional[StrictStr] = Field(default='', description="unique id of ical events")
    visible: Optional[StrictInt] = Field(description="visible")
    __properties: ClassVar[List[str]] = ["courseid", "description", "eventtype", "format", "groupid", "id", "instance", "modulename", "name", "repeatid", "sequence", "subscriptionid", "timeduration", "timemodified", "timestart", "userid", "uuid", "visible"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CoreCalendarCreateCalendarEventsResponseEventsInner from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if courseid (nullable) is None
        # and model_fields_set contains the field
        if self.courseid is None and "courseid" in self.model_fields_set:
            _dict['courseid'] = None

        # set to None if description (nullable) is None
        # and model_fields_set contains the field
        if self.description is None and "description" in self.model_fields_set:
            _dict['description'] = None

        # set to None if eventtype (nullable) is None
        # and model_fields_set contains the field
        if self.eventtype is None and "eventtype" in self.model_fields_set:
            _dict['eventtype'] = None

        # set to None if format (nullable) is None
        # and model_fields_set contains the field
        if self.format is None and "format" in self.model_fields_set:
            _dict['format'] = None

        # set to None if groupid (nullable) is None
        # and model_fields_set contains the field
        if self.groupid is None and "groupid" in self.model_fields_set:
            _dict['groupid'] = None

        # set to None if id (nullable) is None
        # and model_fields_set contains the field
        if self.id is None and "id" in self.model_fields_set:
            _dict['id'] = None

        # set to None if instance (nullable) is None
        # and model_fields_set contains the field
        if self.instance is None and "instance" in self.model_fields_set:
            _dict['instance'] = None

        # set to None if modulename (nullable) is None
        # and model_fields_set contains the field
        if self.modulename is None and "modulename" in self.model_fields_set:
            _dict['modulename'] = None

        # set to None if name (nullable) is None
        # and model_fields_set contains the field
        if self.name is None and "name" in self.model_fields_set:
            _dict['name'] = None

        # set to None if repeatid (nullable) is None
        # and model_fields_set contains the field
        if self.repeatid is None and "repeatid" in self.model_fields_set:
            _dict['repeatid'] = None

        # set to None if sequence (nullable) is None
        # and model_fields_set contains the field
        if self.sequence is None and "sequence" in self.model_fields_set:
            _dict['sequence'] = None

        # set to None if subscriptionid (nullable) is None
        # and model_fields_set contains the field
        if self.subscriptionid is None and "subscriptionid" in self.model_fields_set:
            _dict['subscriptionid'] = None

        # set to None if timeduration (nullable) is None
        # and model_fields_set contains the field
        if self.timeduration is None and "timeduration" in self.model_fields_set:
            _dict['timeduration'] = None

        # set to None if timemodified (nullable) is None
        # and model_fields_set contains the field
        if self.timemodified is None and "timemodified" in self.model_fields_set:
            _dict['timemodified'] = None

        # set to None if timestart (nullable) is None
        # and model_fields_set contains the field
        if self.timestart is None and "timestart" in self.model_fields_set:
            _dict['timestart'] = None

        # set to None if userid (nullable) is None
        # and model_fields_set contains the field
        if self.userid is None and "userid" in self.model_fields_set:
            _dict['userid'] = None

        # set to None if visible (nullable) is None
        # and model_fields_set contains the field
        if self.visible is None and "visible" in self.model_fields_set:
            _dict['visible'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CoreCalendarCreateCalendarEventsResponseEventsInner from a dict"""
        if obj is None:
            return None

        relaxed = settings.relaxe_all_models or "CoreCalendarCreateCalendarEventsResponseEventsInner" in settings.relaxed_models

        if not isinstance(obj, dict):
            return cls.model_construct(**obj) if relaxed else cls.model_validate(obj)

        data = {
            "courseid": obj.get("courseid"),
            "description": obj.get("description"),
            "eventtype": obj.get("eventtype"),
            "format": obj.get("format"),
            "groupid": obj.get("groupid"),
            "id": obj.get("id"),
            "instance": obj.get("instance"),
            "modulename": obj.get("modulename"),
            "name": obj.get("name"),
            "repeatid": obj.get("repeatid"),
            "sequence": obj.get("sequence"),
            "subscriptionid": obj.get("subscriptionid"),
            "timeduration": obj.get("timeduration"),
            "timemodified": obj.get("timemodified"),
            "timestart": obj.get("timestart"),
            "userid": obj.get("userid"),
            "uuid": obj.get("uuid") if obj.get("uuid") is not None else '',
            "visible": obj.get("visible")
        }
        _obj = cls.model_construct(**data) if relaxed else cls.model_validate(data)
        return _obj





# coding: utf-8

"""
    Moodle Webservice API

    Auto-generated OpenAPI spec for Moodle's Webservice API.

    The version of the OpenAPI document: 5.0.3 (Build: 20251006)
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from poodle_async_full.models.core_block_get_course_blocks_response_blocks_inner_contents_files_inner import CoreBlockGetCourseBlocksResponseBlocksInnerContentsFilesInner
from poodle_async_full.models.mod_assign_get_assignments_response_courses_inner_assignments_inner_configs_inner import ModAssignGetAssignmentsResponseCoursesInnerAssignmentsInnerConfigsInner
from typing import Optional, Set
from typing_extensions import Self

from poodle_async_full.configuration import settings

class ModAssignGetAssignmentsResponseCoursesInnerAssignmentsInner(BaseModel):
    """
    assignment information object
    """ # noqa: E501
    activity: Optional[StrictStr] = Field(default=None, description="Description of activity")
    activityattachments: Optional[List[CoreBlockGetCourseBlocksResponseBlocksInnerContentsFilesInner]] = Field(default=None, description="Files from activity field")
    activityformat: Optional[StrictInt] = Field(default=None, description="activity format (1 = HTML, 0 = MOODLE, 2 = PLAIN, or 4 = MARKDOWN)")
    allowsubmissionsfromdate: Optional[StrictInt] = Field(description="allow submissions from date")
    attemptreopenmethod: Optional[StrictStr] = Field(description="method used to control opening new attempts")
    blindmarking: Optional[StrictInt] = Field(description="if enabled, hide identities until reveal identities actioned")
    cmid: Optional[StrictInt] = Field(description="course module id")
    completionsubmit: Optional[StrictInt] = Field(description="if enabled, set activity as complete following submission")
    configs: List[ModAssignGetAssignmentsResponseCoursesInnerAssignmentsInnerConfigsInner] = Field(description="configuration settings")
    course: Optional[StrictInt] = Field(description="course id")
    cutoffdate: Optional[StrictInt] = Field(description="date after which submission is not accepted without an extension")
    duedate: Optional[StrictInt] = Field(description="assignment due date")
    grade: Optional[StrictInt] = Field(description="grade type")
    gradepenalty: Optional[StrictInt] = Field(description="if enabled, penalty will be applied to late submissions")
    gradingduedate: Optional[StrictInt] = Field(description="the expected date for marking the submissions")
    hidegrader: Optional[StrictInt] = Field(description="If enabled, hide grader to student")
    id: Optional[StrictInt] = Field(description="assignment id")
    intro: Optional[StrictStr] = Field(default=None, description="assignment intro, not allways returned because it deppends on the activity configuration")
    introattachments: Optional[List[CoreBlockGetCourseBlocksResponseBlocksInnerContentsFilesInner]] = Field(default=None, description="intro attachments files")
    introfiles: Optional[List[CoreBlockGetCourseBlocksResponseBlocksInnerContentsFilesInner]] = Field(default=None, description="Files in the introduction text")
    introformat: Optional[StrictInt] = Field(default=None, description="intro format (1 = HTML, 0 = MOODLE, 2 = PLAIN, or 4 = MARKDOWN)")
    markingallocation: Optional[StrictInt] = Field(description="enable marking allocation")
    markinganonymous: Optional[StrictInt] = Field(description="enable marking anonymous")
    markingworkflow: Optional[StrictInt] = Field(description="enable marking workflow")
    maxattempts: Optional[StrictInt] = Field(description="maximum number of attempts allowed")
    name: Optional[StrictStr] = Field(description="assignment name")
    nosubmissions: Optional[StrictInt] = Field(description="no submissions")
    preventsubmissionnotingroup: Optional[StrictInt] = Field(default=None, description="Prevent submission not in group")
    requireallteammemberssubmit: Optional[StrictInt] = Field(description="if enabled, all team members must submit")
    requiresubmissionstatement: Optional[StrictInt] = Field(description="student must accept submission statement")
    revealidentities: Optional[StrictInt] = Field(description="show identities for a blind marking assignment")
    sendlatenotifications: Optional[StrictInt] = Field(description="send notifications")
    sendnotifications: Optional[StrictInt] = Field(description="send notifications")
    sendstudentnotifications: Optional[StrictInt] = Field(description="send student notifications (default)")
    submissionattachments: Optional[StrictInt] = Field(default=None, description="Flag to only show files during submission")
    submissiondrafts: Optional[StrictInt] = Field(description="submissions drafts")
    submissionstatement: Optional[StrictStr] = Field(default=None, description="Submission statement formatted.")
    submissionstatementformat: Optional[StrictInt] = Field(default=None, description="submissionstatement format (1 = HTML, 0 = MOODLE, 2 = PLAIN, or 4 = MARKDOWN)")
    teamsubmission: Optional[StrictInt] = Field(description="if enabled, students submit as a team")
    teamsubmissiongroupingid: Optional[StrictInt] = Field(description="the grouping id for the team submission groups")
    timelimit: Optional[StrictInt] = Field(default=None, description="Time limit to complete assigment")
    timemodified: Optional[StrictInt] = Field(description="last time assignment was modified")
    __properties: ClassVar[List[str]] = ["activity", "activityattachments", "activityformat", "allowsubmissionsfromdate", "attemptreopenmethod", "blindmarking", "cmid", "completionsubmit", "configs", "course", "cutoffdate", "duedate", "grade", "gradepenalty", "gradingduedate", "hidegrader", "id", "intro", "introattachments", "introfiles", "introformat", "markingallocation", "markinganonymous", "markingworkflow", "maxattempts", "name", "nosubmissions", "preventsubmissionnotingroup", "requireallteammemberssubmit", "requiresubmissionstatement", "revealidentities", "sendlatenotifications", "sendnotifications", "sendstudentnotifications", "submissionattachments", "submissiondrafts", "submissionstatement", "submissionstatementformat", "teamsubmission", "teamsubmissiongroupingid", "timelimit", "timemodified"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ModAssignGetAssignmentsResponseCoursesInnerAssignmentsInner from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in activityattachments (list)
        _items = []
        if self.activityattachments:
            for _item_activityattachments in self.activityattachments:
                if _item_activityattachments:
                    _items.append(_item_activityattachments.to_dict())
            _dict['activityattachments'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in configs (list)
        _items = []
        if self.configs:
            for _item_configs in self.configs:
                if _item_configs:
                    _items.append(_item_configs.to_dict())
            _dict['configs'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in introattachments (list)
        _items = []
        if self.introattachments:
            for _item_introattachments in self.introattachments:
                if _item_introattachments:
                    _items.append(_item_introattachments.to_dict())
            _dict['introattachments'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in introfiles (list)
        _items = []
        if self.introfiles:
            for _item_introfiles in self.introfiles:
                if _item_introfiles:
                    _items.append(_item_introfiles.to_dict())
            _dict['introfiles'] = _items
        # set to None if activity (nullable) is None
        # and model_fields_set contains the field
        if self.activity is None and "activity" in self.model_fields_set:
            _dict['activity'] = None

        # set to None if activityformat (nullable) is None
        # and model_fields_set contains the field
        if self.activityformat is None and "activityformat" in self.model_fields_set:
            _dict['activityformat'] = None

        # set to None if allowsubmissionsfromdate (nullable) is None
        # and model_fields_set contains the field
        if self.allowsubmissionsfromdate is None and "allowsubmissionsfromdate" in self.model_fields_set:
            _dict['allowsubmissionsfromdate'] = None

        # set to None if attemptreopenmethod (nullable) is None
        # and model_fields_set contains the field
        if self.attemptreopenmethod is None and "attemptreopenmethod" in self.model_fields_set:
            _dict['attemptreopenmethod'] = None

        # set to None if blindmarking (nullable) is None
        # and model_fields_set contains the field
        if self.blindmarking is None and "blindmarking" in self.model_fields_set:
            _dict['blindmarking'] = None

        # set to None if cmid (nullable) is None
        # and model_fields_set contains the field
        if self.cmid is None and "cmid" in self.model_fields_set:
            _dict['cmid'] = None

        # set to None if completionsubmit (nullable) is None
        # and model_fields_set contains the field
        if self.completionsubmit is None and "completionsubmit" in self.model_fields_set:
            _dict['completionsubmit'] = None

        # set to None if course (nullable) is None
        # and model_fields_set contains the field
        if self.course is None and "course" in self.model_fields_set:
            _dict['course'] = None

        # set to None if cutoffdate (nullable) is None
        # and model_fields_set contains the field
        if self.cutoffdate is None and "cutoffdate" in self.model_fields_set:
            _dict['cutoffdate'] = None

        # set to None if duedate (nullable) is None
        # and model_fields_set contains the field
        if self.duedate is None and "duedate" in self.model_fields_set:
            _dict['duedate'] = None

        # set to None if grade (nullable) is None
        # and model_fields_set contains the field
        if self.grade is None and "grade" in self.model_fields_set:
            _dict['grade'] = None

        # set to None if gradepenalty (nullable) is None
        # and model_fields_set contains the field
        if self.gradepenalty is None and "gradepenalty" in self.model_fields_set:
            _dict['gradepenalty'] = None

        # set to None if gradingduedate (nullable) is None
        # and model_fields_set contains the field
        if self.gradingduedate is None and "gradingduedate" in self.model_fields_set:
            _dict['gradingduedate'] = None

        # set to None if hidegrader (nullable) is None
        # and model_fields_set contains the field
        if self.hidegrader is None and "hidegrader" in self.model_fields_set:
            _dict['hidegrader'] = None

        # set to None if id (nullable) is None
        # and model_fields_set contains the field
        if self.id is None and "id" in self.model_fields_set:
            _dict['id'] = None

        # set to None if intro (nullable) is None
        # and model_fields_set contains the field
        if self.intro is None and "intro" in self.model_fields_set:
            _dict['intro'] = None

        # set to None if introformat (nullable) is None
        # and model_fields_set contains the field
        if self.introformat is None and "introformat" in self.model_fields_set:
            _dict['introformat'] = None

        # set to None if markingallocation (nullable) is None
        # and model_fields_set contains the field
        if self.markingallocation is None and "markingallocation" in self.model_fields_set:
            _dict['markingallocation'] = None

        # set to None if markinganonymous (nullable) is None
        # and model_fields_set contains the field
        if self.markinganonymous is None and "markinganonymous" in self.model_fields_set:
            _dict['markinganonymous'] = None

        # set to None if markingworkflow (nullable) is None
        # and model_fields_set contains the field
        if self.markingworkflow is None and "markingworkflow" in self.model_fields_set:
            _dict['markingworkflow'] = None

        # set to None if maxattempts (nullable) is None
        # and model_fields_set contains the field
        if self.maxattempts is None and "maxattempts" in self.model_fields_set:
            _dict['maxattempts'] = None

        # set to None if name (nullable) is None
        # and model_fields_set contains the field
        if self.name is None and "name" in self.model_fields_set:
            _dict['name'] = None

        # set to None if nosubmissions (nullable) is None
        # and model_fields_set contains the field
        if self.nosubmissions is None and "nosubmissions" in self.model_fields_set:
            _dict['nosubmissions'] = None

        # set to None if preventsubmissionnotingroup (nullable) is None
        # and model_fields_set contains the field
        if self.preventsubmissionnotingroup is None and "preventsubmissionnotingroup" in self.model_fields_set:
            _dict['preventsubmissionnotingroup'] = None

        # set to None if requireallteammemberssubmit (nullable) is None
        # and model_fields_set contains the field
        if self.requireallteammemberssubmit is None and "requireallteammemberssubmit" in self.model_fields_set:
            _dict['requireallteammemberssubmit'] = None

        # set to None if requiresubmissionstatement (nullable) is None
        # and model_fields_set contains the field
        if self.requiresubmissionstatement is None and "requiresubmissionstatement" in self.model_fields_set:
            _dict['requiresubmissionstatement'] = None

        # set to None if revealidentities (nullable) is None
        # and model_fields_set contains the field
        if self.revealidentities is None and "revealidentities" in self.model_fields_set:
            _dict['revealidentities'] = None

        # set to None if sendlatenotifications (nullable) is None
        # and model_fields_set contains the field
        if self.sendlatenotifications is None and "sendlatenotifications" in self.model_fields_set:
            _dict['sendlatenotifications'] = None

        # set to None if sendnotifications (nullable) is None
        # and model_fields_set contains the field
        if self.sendnotifications is None and "sendnotifications" in self.model_fields_set:
            _dict['sendnotifications'] = None

        # set to None if sendstudentnotifications (nullable) is None
        # and model_fields_set contains the field
        if self.sendstudentnotifications is None and "sendstudentnotifications" in self.model_fields_set:
            _dict['sendstudentnotifications'] = None

        # set to None if submissionattachments (nullable) is None
        # and model_fields_set contains the field
        if self.submissionattachments is None and "submissionattachments" in self.model_fields_set:
            _dict['submissionattachments'] = None

        # set to None if submissiondrafts (nullable) is None
        # and model_fields_set contains the field
        if self.submissiondrafts is None and "submissiondrafts" in self.model_fields_set:
            _dict['submissiondrafts'] = None

        # set to None if submissionstatement (nullable) is None
        # and model_fields_set contains the field
        if self.submissionstatement is None and "submissionstatement" in self.model_fields_set:
            _dict['submissionstatement'] = None

        # set to None if submissionstatementformat (nullable) is None
        # and model_fields_set contains the field
        if self.submissionstatementformat is None and "submissionstatementformat" in self.model_fields_set:
            _dict['submissionstatementformat'] = None

        # set to None if teamsubmission (nullable) is None
        # and model_fields_set contains the field
        if self.teamsubmission is None and "teamsubmission" in self.model_fields_set:
            _dict['teamsubmission'] = None

        # set to None if teamsubmissiongroupingid (nullable) is None
        # and model_fields_set contains the field
        if self.teamsubmissiongroupingid is None and "teamsubmissiongroupingid" in self.model_fields_set:
            _dict['teamsubmissiongroupingid'] = None

        # set to None if timelimit (nullable) is None
        # and model_fields_set contains the field
        if self.timelimit is None and "timelimit" in self.model_fields_set:
            _dict['timelimit'] = None

        # set to None if timemodified (nullable) is None
        # and model_fields_set contains the field
        if self.timemodified is None and "timemodified" in self.model_fields_set:
            _dict['timemodified'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ModAssignGetAssignmentsResponseCoursesInnerAssignmentsInner from a dict"""
        if obj is None:
            return None

        relaxed = settings.relaxe_all_models or "ModAssignGetAssignmentsResponseCoursesInnerAssignmentsInner" in settings.relaxed_models

        if not isinstance(obj, dict):
            return cls.model_construct(**obj) if relaxed else cls.model_validate(obj)

        data = {
            "activity": obj.get("activity"),
            "activityattachments": [CoreBlockGetCourseBlocksResponseBlocksInnerContentsFilesInner.from_dict(_item) for _item in obj["activityattachments"]] if obj.get("activityattachments") is not None else None,
            "activityformat": obj.get("activityformat"),
            "allowsubmissionsfromdate": obj.get("allowsubmissionsfromdate"),
            "attemptreopenmethod": obj.get("attemptreopenmethod"),
            "blindmarking": obj.get("blindmarking"),
            "cmid": obj.get("cmid"),
            "completionsubmit": obj.get("completionsubmit"),
            "configs": [ModAssignGetAssignmentsResponseCoursesInnerAssignmentsInnerConfigsInner.from_dict(_item) for _item in obj["configs"]] if obj.get("configs") is not None else None,
            "course": obj.get("course"),
            "cutoffdate": obj.get("cutoffdate"),
            "duedate": obj.get("duedate"),
            "grade": obj.get("grade"),
            "gradepenalty": obj.get("gradepenalty"),
            "gradingduedate": obj.get("gradingduedate"),
            "hidegrader": obj.get("hidegrader"),
            "id": obj.get("id"),
            "intro": obj.get("intro"),
            "introattachments": [CoreBlockGetCourseBlocksResponseBlocksInnerContentsFilesInner.from_dict(_item) for _item in obj["introattachments"]] if obj.get("introattachments") is not None else None,
            "introfiles": [CoreBlockGetCourseBlocksResponseBlocksInnerContentsFilesInner.from_dict(_item) for _item in obj["introfiles"]] if obj.get("introfiles") is not None else None,
            "introformat": obj.get("introformat"),
            "markingallocation": obj.get("markingallocation"),
            "markinganonymous": obj.get("markinganonymous"),
            "markingworkflow": obj.get("markingworkflow"),
            "maxattempts": obj.get("maxattempts"),
            "name": obj.get("name"),
            "nosubmissions": obj.get("nosubmissions"),
            "preventsubmissionnotingroup": obj.get("preventsubmissionnotingroup"),
            "requireallteammemberssubmit": obj.get("requireallteammemberssubmit"),
            "requiresubmissionstatement": obj.get("requiresubmissionstatement"),
            "revealidentities": obj.get("revealidentities"),
            "sendlatenotifications": obj.get("sendlatenotifications"),
            "sendnotifications": obj.get("sendnotifications"),
            "sendstudentnotifications": obj.get("sendstudentnotifications"),
            "submissionattachments": obj.get("submissionattachments"),
            "submissiondrafts": obj.get("submissiondrafts"),
            "submissionstatement": obj.get("submissionstatement"),
            "submissionstatementformat": obj.get("submissionstatementformat"),
            "teamsubmission": obj.get("teamsubmission"),
            "teamsubmissiongroupingid": obj.get("teamsubmissiongroupingid"),
            "timelimit": obj.get("timelimit"),
            "timemodified": obj.get("timemodified")
        }
        _obj = cls.model_construct(**data) if relaxed else cls.model_validate(data)
        return _obj





# coding: utf-8

"""
    Moodle Webservice API

    Auto-generated OpenAPI spec for Moodle's Webservice API.

    The version of the OpenAPI document: 5.0.3 (Build: 20251006)
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from poodle_async_full.models.core_block_get_course_blocks_response_blocks_inner_contents_files_inner import CoreBlockGetCourseBlocksResponseBlocksInnerContentsFilesInner
from typing import Optional, Set
from typing_extensions import Self

from poodle_async_full.configuration import settings

class ModForumGetForumsByCoursesResponseInner(BaseModel):
    """
    forum
    """ # noqa: E501
    assessed: Optional[StrictInt] = Field(description="Aggregate type")
    assesstimefinish: Optional[StrictInt] = Field(description="Assess finish time")
    assesstimestart: Optional[StrictInt] = Field(description="Assess start time")
    blockafter: Optional[StrictInt] = Field(description="Post threshold for blocking")
    blockperiod: Optional[StrictInt] = Field(description="Time period for blocking")
    cancreatediscussions: Optional[StrictBool] = Field(default=None, description="If the user can create discussions")
    cmid: Optional[StrictInt] = Field(description="Course module id")
    completiondiscussions: Optional[StrictInt] = Field(description="Student must create discussions")
    completionposts: Optional[StrictInt] = Field(description="Student must post discussions or replies")
    completionreplies: Optional[StrictInt] = Field(description="Student must post replies")
    course: Optional[StrictInt] = Field(description="Course id")
    cutoffdate: Optional[StrictInt] = Field(default=None, description="cutoffdate for the user")
    duedate: Optional[StrictInt] = Field(default=None, description="duedate for the user")
    forcesubscribe: Optional[StrictInt] = Field(description="Force users to subscribe")
    grade_forum: Optional[StrictInt] = Field(description="Whole forum grade")
    grade_forum_notify: Optional[StrictInt] = Field(description="Whether to send notifications to students upon grading by default")
    id: Optional[StrictInt] = Field(description="Forum id")
    intro: Optional[StrictStr] = Field(description="The forum intro")
    introfiles: Optional[List[CoreBlockGetCourseBlocksResponseBlocksInnerContentsFilesInner]] = Field(default=None, description="Files in the introduction text")
    introformat: Optional[StrictInt] = Field(description="intro format (1 = HTML, 0 = MOODLE, 2 = PLAIN, or 4 = MARKDOWN)")
    istracked: Optional[StrictBool] = Field(default=None, description="If the user is tracking the forum")
    lang: Optional[StrictStr] = Field(default=None, description="Forced activity language")
    lockdiscussionafter: Optional[StrictInt] = Field(default=None, description="After what period a discussion is locked")
    maxattachments: Optional[StrictInt] = Field(description="Maximum number of attachments")
    maxbytes: Optional[StrictInt] = Field(description="Maximum attachment size")
    name: Optional[StrictStr] = Field(description="Forum name")
    numdiscussions: Optional[StrictInt] = Field(default=None, description="Number of discussions in the forum")
    rssarticles: Optional[StrictInt] = Field(description="Number of RSS recent articles")
    rsstype: Optional[StrictInt] = Field(description="RSS feed for this activity")
    scale: Optional[StrictInt] = Field(description="Scale")
    timemodified: Optional[StrictInt] = Field(description="Time modified")
    trackingtype: Optional[StrictInt] = Field(description="Subscription mode")
    type: Optional[StrictStr] = Field(description="The forum type")
    unreadpostscount: Optional[StrictInt] = Field(default=None, description="The number of unread posts for tracked forums")
    warnafter: Optional[StrictInt] = Field(description="Post threshold for warning")
    __properties: ClassVar[List[str]] = ["assessed", "assesstimefinish", "assesstimestart", "blockafter", "blockperiod", "cancreatediscussions", "cmid", "completiondiscussions", "completionposts", "completionreplies", "course", "cutoffdate", "duedate", "forcesubscribe", "grade_forum", "grade_forum_notify", "id", "intro", "introfiles", "introformat", "istracked", "lang", "lockdiscussionafter", "maxattachments", "maxbytes", "name", "numdiscussions", "rssarticles", "rsstype", "scale", "timemodified", "trackingtype", "type", "unreadpostscount", "warnafter"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ModForumGetForumsByCoursesResponseInner from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in introfiles (list)
        _items = []
        if self.introfiles:
            for _item_introfiles in self.introfiles:
                if _item_introfiles:
                    _items.append(_item_introfiles.to_dict())
            _dict['introfiles'] = _items
        # set to None if assessed (nullable) is None
        # and model_fields_set contains the field
        if self.assessed is None and "assessed" in self.model_fields_set:
            _dict['assessed'] = None

        # set to None if assesstimefinish (nullable) is None
        # and model_fields_set contains the field
        if self.assesstimefinish is None and "assesstimefinish" in self.model_fields_set:
            _dict['assesstimefinish'] = None

        # set to None if assesstimestart (nullable) is None
        # and model_fields_set contains the field
        if self.assesstimestart is None and "assesstimestart" in self.model_fields_set:
            _dict['assesstimestart'] = None

        # set to None if blockafter (nullable) is None
        # and model_fields_set contains the field
        if self.blockafter is None and "blockafter" in self.model_fields_set:
            _dict['blockafter'] = None

        # set to None if blockperiod (nullable) is None
        # and model_fields_set contains the field
        if self.blockperiod is None and "blockperiod" in self.model_fields_set:
            _dict['blockperiod'] = None

        # set to None if cancreatediscussions (nullable) is None
        # and model_fields_set contains the field
        if self.cancreatediscussions is None and "cancreatediscussions" in self.model_fields_set:
            _dict['cancreatediscussions'] = None

        # set to None if cmid (nullable) is None
        # and model_fields_set contains the field
        if self.cmid is None and "cmid" in self.model_fields_set:
            _dict['cmid'] = None

        # set to None if completiondiscussions (nullable) is None
        # and model_fields_set contains the field
        if self.completiondiscussions is None and "completiondiscussions" in self.model_fields_set:
            _dict['completiondiscussions'] = None

        # set to None if completionposts (nullable) is None
        # and model_fields_set contains the field
        if self.completionposts is None and "completionposts" in self.model_fields_set:
            _dict['completionposts'] = None

        # set to None if completionreplies (nullable) is None
        # and model_fields_set contains the field
        if self.completionreplies is None and "completionreplies" in self.model_fields_set:
            _dict['completionreplies'] = None

        # set to None if course (nullable) is None
        # and model_fields_set contains the field
        if self.course is None and "course" in self.model_fields_set:
            _dict['course'] = None

        # set to None if cutoffdate (nullable) is None
        # and model_fields_set contains the field
        if self.cutoffdate is None and "cutoffdate" in self.model_fields_set:
            _dict['cutoffdate'] = None

        # set to None if duedate (nullable) is None
        # and model_fields_set contains the field
        if self.duedate is None and "duedate" in self.model_fields_set:
            _dict['duedate'] = None

        # set to None if forcesubscribe (nullable) is None
        # and model_fields_set contains the field
        if self.forcesubscribe is None and "forcesubscribe" in self.model_fields_set:
            _dict['forcesubscribe'] = None

        # set to None if grade_forum (nullable) is None
        # and model_fields_set contains the field
        if self.grade_forum is None and "grade_forum" in self.model_fields_set:
            _dict['grade_forum'] = None

        # set to None if grade_forum_notify (nullable) is None
        # and model_fields_set contains the field
        if self.grade_forum_notify is None and "grade_forum_notify" in self.model_fields_set:
            _dict['grade_forum_notify'] = None

        # set to None if id (nullable) is None
        # and model_fields_set contains the field
        if self.id is None and "id" in self.model_fields_set:
            _dict['id'] = None

        # set to None if intro (nullable) is None
        # and model_fields_set contains the field
        if self.intro is None and "intro" in self.model_fields_set:
            _dict['intro'] = None

        # set to None if introformat (nullable) is None
        # and model_fields_set contains the field
        if self.introformat is None and "introformat" in self.model_fields_set:
            _dict['introformat'] = None

        # set to None if istracked (nullable) is None
        # and model_fields_set contains the field
        if self.istracked is None and "istracked" in self.model_fields_set:
            _dict['istracked'] = None

        # set to None if lang (nullable) is None
        # and model_fields_set contains the field
        if self.lang is None and "lang" in self.model_fields_set:
            _dict['lang'] = None

        # set to None if lockdiscussionafter (nullable) is None
        # and model_fields_set contains the field
        if self.lockdiscussionafter is None and "lockdiscussionafter" in self.model_fields_set:
            _dict['lockdiscussionafter'] = None

        # set to None if maxattachments (nullable) is None
        # and model_fields_set contains the field
        if self.maxattachments is None and "maxattachments" in self.model_fields_set:
            _dict['maxattachments'] = None

        # set to None if maxbytes (nullable) is None
        # and model_fields_set contains the field
        if self.maxbytes is None and "maxbytes" in self.model_fields_set:
            _dict['maxbytes'] = None

        # set to None if name (nullable) is None
        # and model_fields_set contains the field
        if self.name is None and "name" in self.model_fields_set:
            _dict['name'] = None

        # set to None if numdiscussions (nullable) is None
        # and model_fields_set contains the field
        if self.numdiscussions is None and "numdiscussions" in self.model_fields_set:
            _dict['numdiscussions'] = None

        # set to None if rssarticles (nullable) is None
        # and model_fields_set contains the field
        if self.rssarticles is None and "rssarticles" in self.model_fields_set:
            _dict['rssarticles'] = None

        # set to None if rsstype (nullable) is None
        # and model_fields_set contains the field
        if self.rsstype is None and "rsstype" in self.model_fields_set:
            _dict['rsstype'] = None

        # set to None if scale (nullable) is None
        # and model_fields_set contains the field
        if self.scale is None and "scale" in self.model_fields_set:
            _dict['scale'] = None

        # set to None if timemodified (nullable) is None
        # and model_fields_set contains the field
        if self.timemodified is None and "timemodified" in self.model_fields_set:
            _dict['timemodified'] = None

        # set to None if trackingtype (nullable) is None
        # and model_fields_set contains the field
        if self.trackingtype is None and "trackingtype" in self.model_fields_set:
            _dict['trackingtype'] = None

        # set to None if type (nullable) is None
        # and model_fields_set contains the field
        if self.type is None and "type" in self.model_fields_set:
            _dict['type'] = None

        # set to None if unreadpostscount (nullable) is None
        # and model_fields_set contains the field
        if self.unreadpostscount is None and "unreadpostscount" in self.model_fields_set:
            _dict['unreadpostscount'] = None

        # set to None if warnafter (nullable) is None
        # and model_fields_set contains the field
        if self.warnafter is None and "warnafter" in self.model_fields_set:
            _dict['warnafter'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ModForumGetForumsByCoursesResponseInner from a dict"""
        if obj is None:
            return None

        relaxed = settings.relaxe_all_models or "ModForumGetForumsByCoursesResponseInner" in settings.relaxed_models

        if not isinstance(obj, dict):
            return cls.model_construct(**obj) if relaxed else cls.model_validate(obj)

        data = {
            "assessed": obj.get("assessed"),
            "assesstimefinish": obj.get("assesstimefinish"),
            "assesstimestart": obj.get("assesstimestart"),
            "blockafter": obj.get("blockafter"),
            "blockperiod": obj.get("blockperiod"),
            "cancreatediscussions": obj.get("cancreatediscussions"),
            "cmid": obj.get("cmid"),
            "completiondiscussions": obj.get("completiondiscussions"),
            "completionposts": obj.get("completionposts"),
            "completionreplies": obj.get("completionreplies"),
            "course": obj.get("course"),
            "cutoffdate": obj.get("cutoffdate"),
            "duedate": obj.get("duedate"),
            "forcesubscribe": obj.get("forcesubscribe"),
            "grade_forum": obj.get("grade_forum"),
            "grade_forum_notify": obj.get("grade_forum_notify"),
            "id": obj.get("id"),
            "intro": obj.get("intro"),
            "introfiles": [CoreBlockGetCourseBlocksResponseBlocksInnerContentsFilesInner.from_dict(_item) for _item in obj["introfiles"]] if obj.get("introfiles") is not None else None,
            "introformat": obj.get("introformat"),
            "istracked": obj.get("istracked"),
            "lang": obj.get("lang"),
            "lockdiscussionafter": obj.get("lockdiscussionafter"),
            "maxattachments": obj.get("maxattachments"),
            "maxbytes": obj.get("maxbytes"),
            "name": obj.get("name"),
            "numdiscussions": obj.get("numdiscussions"),
            "rssarticles": obj.get("rssarticles"),
            "rsstype": obj.get("rsstype"),
            "scale": obj.get("scale"),
            "timemodified": obj.get("timemodified"),
            "trackingtype": obj.get("trackingtype"),
            "type": obj.get("type"),
            "unreadpostscount": obj.get("unreadpostscount"),
            "warnafter": obj.get("warnafter")
        }
        _obj = cls.model_construct(**data) if relaxed else cls.model_validate(data)
        return _obj





# coding: utf-8

"""
    Moodle Webservice API

    Auto-generated OpenAPI spec for Moodle's Webservice API.

    The version of the OpenAPI document: 5.0.3 (Build: 20251006)
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

from poodle_async_full.configuration import settings

class CoreCompetencyCreateCompetencyParametersCompetency(BaseModel):
    """
    CoreCompetencyCreateCompetencyParametersCompetency
    """ # noqa: E501
    competencyframeworkid: Optional[StrictInt] = Field(default=0, description="competencyframeworkid")
    description: Optional[StrictStr] = Field(default='', description="description")
    descriptionformat: Optional[StrictInt] = Field(default=1, description="description format (1 = HTML, 0 = MOODLE, 2 = PLAIN, or 4 = MARKDOWN)")
    idnumber: StrictStr = Field(description="idnumber")
    parentid: Optional[StrictInt] = Field(default=0, description="parentid")
    path: Optional[StrictStr] = Field(default='/0/', description="path")
    ruleconfig: Optional[StrictStr] = Field(default=None, description="ruleconfig")
    ruleoutcome: Optional[StrictInt] = Field(default=0, description="ruleoutcome")
    ruletype: Optional[StrictStr] = Field(default=None, description="ruletype")
    scaleconfiguration: Optional[StrictStr] = Field(default=None, description="scaleconfiguration")
    scaleid: Optional[StrictInt] = Field(default=None, description="scaleid")
    shortname: StrictStr = Field(description="shortname")
    sortorder: Optional[StrictInt] = Field(default=0, description="sortorder")
    timecreated: Optional[StrictInt] = Field(default=0, description="timecreated")
    timemodified: Optional[StrictInt] = Field(default=0, description="timemodified")
    usermodified: Optional[StrictInt] = Field(default=0, description="usermodified")
    __properties: ClassVar[List[str]] = ["competencyframeworkid", "description", "descriptionformat", "idnumber", "parentid", "path", "ruleconfig", "ruleoutcome", "ruletype", "scaleconfiguration", "scaleid", "shortname", "sortorder", "timecreated", "timemodified", "usermodified"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CoreCompetencyCreateCompetencyParametersCompetency from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if descriptionformat (nullable) is None
        # and model_fields_set contains the field
        if self.descriptionformat is None and "descriptionformat" in self.model_fields_set:
            _dict['descriptionformat'] = None

        # set to None if ruleconfig (nullable) is None
        # and model_fields_set contains the field
        if self.ruleconfig is None and "ruleconfig" in self.model_fields_set:
            _dict['ruleconfig'] = None

        # set to None if ruletype (nullable) is None
        # and model_fields_set contains the field
        if self.ruletype is None and "ruletype" in self.model_fields_set:
            _dict['ruletype'] = None

        # set to None if scaleconfiguration (nullable) is None
        # and model_fields_set contains the field
        if self.scaleconfiguration is None and "scaleconfiguration" in self.model_fields_set:
            _dict['scaleconfiguration'] = None

        # set to None if scaleid (nullable) is None
        # and model_fields_set contains the field
        if self.scaleid is None and "scaleid" in self.model_fields_set:
            _dict['scaleid'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CoreCompetencyCreateCompetencyParametersCompetency from a dict"""
        if obj is None:
            return None

        relaxed = settings.relaxe_all_models or "CoreCompetencyCreateCompetencyParametersCompetency" in settings.relaxed_models

        if not isinstance(obj, dict):
            return cls.model_construct(**obj) if relaxed else cls.model_validate(obj)

        data = {
            "competencyframeworkid": obj.get("competencyframeworkid") if obj.get("competencyframeworkid") is not None else 0,
            "description": obj.get("description") if obj.get("description") is not None else '',
            "descriptionformat": obj.get("descriptionformat") if obj.get("descriptionformat") is not None else 1,
            "idnumber": obj.get("idnumber") if obj.get("idnumber") is not None else '',
            "parentid": obj.get("parentid") if obj.get("parentid") is not None else 0,
            "path": obj.get("path") if obj.get("path") is not None else '/0/',
            "ruleconfig": obj.get("ruleconfig"),
            "ruleoutcome": obj.get("ruleoutcome") if obj.get("ruleoutcome") is not None else 0,
            "ruletype": obj.get("ruletype"),
            "scaleconfiguration": obj.get("scaleconfiguration"),
            "scaleid": obj.get("scaleid"),
            "shortname": obj.get("shortname") if obj.get("shortname") is not None else '',
            "sortorder": obj.get("sortorder") if obj.get("sortorder") is not None else 0,
            "timecreated": obj.get("timecreated") if obj.get("timecreated") is not None else 0,
            "timemodified": obj.get("timemodified") if obj.get("timemodified") is not None else 0,
            "usermodified": obj.get("usermodified") if obj.get("usermodified") is not None else 0
        }
        _obj = cls.model_construct(**data) if relaxed else cls.model_validate(data)
        return _obj





# coding: utf-8

"""
    Moodle Webservice API

    Auto-generated OpenAPI spec for Moodle's Webservice API.

    The version of the OpenAPI document: 5.0.3 (Build: 20251006)
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from poodle_async_full.models.core_competency_read_user_evidence_response_files_inner import CoreCompetencyReadUserEvidenceResponseFilesInner
from poodle_async_full.models.mod_forum_add_discussion_post_response_post_attachments_inner import ModForumAddDiscussionPostResponsePostAttachmentsInner
from poodle_async_full.models.mod_forum_add_discussion_post_response_post_author import ModForumAddDiscussionPostResponsePostAuthor
from poodle_async_full.models.mod_forum_add_discussion_post_response_post_capabilities import ModForumAddDiscussionPostResponsePostCapabilities
from poodle_async_full.models.mod_forum_add_discussion_post_response_post_html import ModForumAddDiscussionPostResponsePostHtml
from poodle_async_full.models.mod_forum_add_discussion_post_response_post_tags_inner import ModForumAddDiscussionPostResponsePostTagsInner
from poodle_async_full.models.mod_forum_add_discussion_post_response_post_urls import ModForumAddDiscussionPostResponsePostUrls
from typing import Optional, Set
from typing_extensions import Self

from poodle_async_full.configuration import settings

class ModForumAddDiscussionPostResponsePost(BaseModel):
    """
    ModForumAddDiscussionPostResponsePost
    """ # noqa: E501
    attachments: List[ModForumAddDiscussionPostResponsePostAttachmentsInner] = Field(description="attachments")
    author: ModForumAddDiscussionPostResponsePostAuthor
    capabilities: ModForumAddDiscussionPostResponsePostCapabilities
    charcount: Optional[StrictInt] = Field(default=None, description="charcount")
    discussionid: StrictInt = Field(description="discussionid")
    hasparent: StrictBool = Field(description="hasparent")
    haswordcount: StrictBool = Field(description="haswordcount")
    html: Optional[ModForumAddDiscussionPostResponsePostHtml] = None
    id: StrictInt = Field(description="id")
    isdeleted: StrictBool = Field(description="isdeleted")
    isprivatereply: StrictBool = Field(description="isprivatereply")
    message: StrictStr = Field(description="message")
    messageformat: Optional[StrictInt] = Field(description="message format (1 = HTML, 0 = MOODLE, 2 = PLAIN, or 4 = MARKDOWN)")
    messageinlinefiles: Optional[List[CoreCompetencyReadUserEvidenceResponseFilesInner]] = Field(default=None, description="messageinlinefiles")
    parentid: Optional[StrictInt] = Field(default=None, description="parentid")
    replysubject: StrictStr = Field(description="replysubject")
    subject: StrictStr = Field(description="subject")
    tags: Optional[List[ModForumAddDiscussionPostResponsePostTagsInner]] = Field(default=None, description="tags")
    timecreated: Optional[StrictInt] = Field(description="timecreated")
    timemodified: Optional[StrictInt] = Field(description="timemodified")
    unread: Optional[StrictBool] = Field(default=None, description="unread")
    urls: Optional[ModForumAddDiscussionPostResponsePostUrls] = None
    wordcount: Optional[StrictInt] = Field(default=None, description="wordcount")
    __properties: ClassVar[List[str]] = ["attachments", "author", "capabilities", "charcount", "discussionid", "hasparent", "haswordcount", "html", "id", "isdeleted", "isprivatereply", "message", "messageformat", "messageinlinefiles", "parentid", "replysubject", "subject", "tags", "timecreated", "timemodified", "unread", "urls", "wordcount"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ModForumAddDiscussionPostResponsePost from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in attachments (list)
        _items = []
        if self.attachments:
            for _item_attachments in self.attachments:
                if _item_attachments:
                    _items.append(_item_attachments.to_dict())
            _dict['attachments'] = _items
        # override the default output from pydantic by calling `to_dict()` of author
        if self.author:
            _dict['author'] = self.author.to_dict()
        # override the default output from pydantic by calling `to_dict()` of capabilities
        if self.capabilities:
            _dict['capabilities'] = self.capabilities.to_dict()
        # override the default output from pydantic by calling `to_dict()` of html
        if self.html:
            _dict['html'] = self.html.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in messageinlinefiles (list)
        _items = []
        if self.messageinlinefiles:
            for _item_messageinlinefiles in self.messageinlinefiles:
                if _item_messageinlinefiles:
                    _items.append(_item_messageinlinefiles.to_dict())
            _dict['messageinlinefiles'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in tags (list)
        _items = []
        if self.tags:
            for _item_tags in self.tags:
                if _item_tags:
                    _items.append(_item_tags.to_dict())
            _dict['tags'] = _items
        # override the default output from pydantic by calling `to_dict()` of urls
        if self.urls:
            _dict['urls'] = self.urls.to_dict()
        # set to None if charcount (nullable) is None
        # and model_fields_set contains the field
        if self.charcount is None and "charcount" in self.model_fields_set:
            _dict['charcount'] = None

        # set to None if messageformat (nullable) is None
        # and model_fields_set contains the field
        if self.messageformat is None and "messageformat" in self.model_fields_set:
            _dict['messageformat'] = None

        # set to None if parentid (nullable) is None
        # and model_fields_set contains the field
        if self.parentid is None and "parentid" in self.model_fields_set:
            _dict['parentid'] = None

        # set to None if timecreated (nullable) is None
        # and model_fields_set contains the field
        if self.timecreated is None and "timecreated" in self.model_fields_set:
            _dict['timecreated'] = None

        # set to None if timemodified (nullable) is None
        # and model_fields_set contains the field
        if self.timemodified is None and "timemodified" in self.model_fields_set:
            _dict['timemodified'] = None

        # set to None if unread (nullable) is None
        # and model_fields_set contains the field
        if self.unread is None and "unread" in self.model_fields_set:
            _dict['unread'] = None

        # set to None if wordcount (nullable) is None
        # and model_fields_set contains the field
        if self.wordcount is None and "wordcount" in self.model_fields_set:
            _dict['wordcount'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ModForumAddDiscussionPostResponsePost from a dict"""
        if obj is None:
            return None

        relaxed = settings.relaxe_all_models or "ModForumAddDiscussionPostResponsePost" in settings.relaxed_models

        if not isinstance(obj, dict):
            return cls.model_construct(**obj) if relaxed else cls.model_validate(obj)

        data = {
            "attachments": [ModForumAddDiscussionPostResponsePostAttachmentsInner.from_dict(_item) for _item in obj["attachments"]] if obj.get("attachments") is not None else None,
            "author": ModForumAddDiscussionPostResponsePostAuthor.from_dict(obj["author"]) if obj.get("author") is not None else None,
            "capabilities": ModForumAddDiscussionPostResponsePostCapabilities.from_dict(obj["capabilities"]) if obj.get("capabilities") is not None else None,
            "charcount": obj.get("charcount"),
            "discussionid": obj.get("discussionid") if obj.get("discussionid") is not None else 0,
            "hasparent": obj.get("hasparent") if obj.get("hasparent") is not None else False,
            "haswordcount": obj.get("haswordcount") if obj.get("haswordcount") is not None else False,
            "html": ModForumAddDiscussionPostResponsePostHtml.from_dict(obj["html"]) if obj.get("html") is not None else None,
            "id": obj.get("id") if obj.get("id") is not None else 0,
            "isdeleted": obj.get("isdeleted") if obj.get("isdeleted") is not None else False,
            "isprivatereply": obj.get("isprivatereply") if obj.get("isprivatereply") is not None else False,
            "message": obj.get("message") if obj.get("message") is not None else '',
            "messageformat": obj.get("messageformat"),
            "messageinlinefiles": [CoreCompetencyReadUserEvidenceResponseFilesInner.from_dict(_item) for _item in obj["messageinlinefiles"]] if obj.get("messageinlinefiles") is not None else None,
            "parentid": obj.get("parentid"),
            "replysubject": obj.get("replysubject") if obj.get("replysubject") is not None else '',
            "subject": obj.get("subject") if obj.get("subject") is not None else '',
            "tags": [ModForumAddDiscussionPostResponsePostTagsInner.from_dict(_item) for _item in obj["tags"]] if obj.get("tags") is not None else None,
            "timecreated": obj.get("timecreated"),
            "timemodified": obj.get("timemodified"),
            "unread": obj.get("unread"),
            "urls": ModForumAddDiscussionPostResponsePostUrls.from_dict(obj["urls"]) if obj.get("urls") is not None else None,
            "wordcount": obj.get("wordcount")
        }
        _obj = cls.model_construct(**data) if relaxed else cls.model_validate(data)
        return _obj





# coding: utf-8

"""
    Moodle Webservice API

    Auto-generated OpenAPI spec for Moodle's Webservice API.

    The version of the OpenAPI document: 5.0.3 (Build: 20251006)
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictFloat, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from poodle_async_full.models.mod_workshop_get_grades_report_response_report_grades_inner_reviewedby_inner import ModWorkshopGetGradesReportResponseReportGradesInnerReviewedbyInner
from typing import Optional, Set
from typing_extensions import Self

from poodle_async_full.configuration import settings

class ModWorkshopGetGradesReportResponseReportGradesInner(BaseModel):
    """
    ModWorkshopGetGradesReportResponseReportGradesInner
    """ # noqa: E501
    gradinggrade: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="Computed grade for the assessment.")
    reviewedby: Optional[List[ModWorkshopGetGradesReportResponseReportGradesInnerReviewedbyInner]] = Field(default=None, description="The users who reviewed the                                         user submission.")
    reviewerof: Optional[List[ModWorkshopGetGradesReportResponseReportGradesInnerReviewedbyInner]] = Field(default=None, description="The assessments the user                                         reviewed.")
    submissiongrade: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="Aggregated grade for the submission.")
    submissiongradeover: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="Grade for the assessment overrided                                         by the teacher.")
    submissiongradeoverby: Optional[StrictInt] = Field(default=None, description="The id of the user who overrided                                         the grade.")
    submissionid: Optional[StrictInt] = Field(description="Submission id.")
    submissionmodified: Optional[StrictInt] = Field(description="Timestamp submission was updated.")
    submissionpublished: Optional[StrictInt] = Field(default=None, description="Whether is a submission published.")
    submissiontitle: Optional[StrictStr] = Field(description="Submission title.")
    userid: Optional[StrictInt] = Field(description="The id of the user being displayed in the report.")
    __properties: ClassVar[List[str]] = ["gradinggrade", "reviewedby", "reviewerof", "submissiongrade", "submissiongradeover", "submissiongradeoverby", "submissionid", "submissionmodified", "submissionpublished", "submissiontitle", "userid"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ModWorkshopGetGradesReportResponseReportGradesInner from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in reviewedby (list)
        _items = []
        if self.reviewedby:
            for _item_reviewedby in self.reviewedby:
                if _item_reviewedby:
                    _items.append(_item_reviewedby.to_dict())
            _dict['reviewedby'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in reviewerof (list)
        _items = []
        if self.reviewerof:
            for _item_reviewerof in self.reviewerof:
                if _item_reviewerof:
                    _items.append(_item_reviewerof.to_dict())
            _dict['reviewerof'] = _items
        # set to None if gradinggrade (nullable) is None
        # and model_fields_set contains the field
        if self.gradinggrade is None and "gradinggrade" in self.model_fields_set:
            _dict['gradinggrade'] = None

        # set to None if submissiongrade (nullable) is None
        # and model_fields_set contains the field
        if self.submissiongrade is None and "submissiongrade" in self.model_fields_set:
            _dict['submissiongrade'] = None

        # set to None if submissiongradeover (nullable) is None
        # and model_fields_set contains the field
        if self.submissiongradeover is None and "submissiongradeover" in self.model_fields_set:
            _dict['submissiongradeover'] = None

        # set to None if submissiongradeoverby (nullable) is None
        # and model_fields_set contains the field
        if self.submissiongradeoverby is None and "submissiongradeoverby" in self.model_fields_set:
            _dict['submissiongradeoverby'] = None

        # set to None if submissionid (nullable) is None
        # and model_fields_set contains the field
        if self.submissionid is None and "submissionid" in self.model_fields_set:
            _dict['submissionid'] = None

        # set to None if submissionmodified (nullable) is None
        # and model_fields_set contains the field
        if self.submissionmodified is None and "submissionmodified" in self.model_fields_set:
            _dict['submissionmodified'] = None

        # set to None if submissionpublished (nullable) is None
        # and model_fields_set contains the field
        if self.submissionpublished is None and "submissionpublished" in self.model_fields_set:
            _dict['submissionpublished'] = None

        # set to None if submissiontitle (nullable) is None
        # and model_fields_set contains the field
        if self.submissiontitle is None and "submissiontitle" in self.model_fields_set:
            _dict['submissiontitle'] = None

        # set to None if userid (nullable) is None
        # and model_fields_set contains the field
        if self.userid is None and "userid" in self.model_fields_set:
            _dict['userid'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ModWorkshopGetGradesReportResponseReportGradesInner from a dict"""
        if obj is None:
            return None

        relaxed = settings.relaxe_all_models or "ModWorkshopGetGradesReportResponseReportGradesInner" in settings.relaxed_models

        if not isinstance(obj, dict):
            return cls.model_construct(**obj) if relaxed else cls.model_validate(obj)

        data = {
            "gradinggrade": obj.get("gradinggrade"),
            "reviewedby": [ModWorkshopGetGradesReportResponseReportGradesInnerReviewedbyInner.from_dict(_item) for _item in obj["reviewedby"]] if obj.get("reviewedby") is not None else None,
            "reviewerof": [ModWorkshopGetGradesReportResponseReportGradesInnerReviewedbyInner.from_dict(_item) for _item in obj["reviewerof"]] if obj.get("reviewerof") is not None else None,
            "submissiongrade": obj.get("submissiongrade"),
            "submissiongradeover": obj.get("submissiongradeover"),
            "submissiongradeoverby": obj.get("submissiongradeoverby"),
            "submissionid": obj.get("submissionid"),
            "submissionmodified": obj.get("submissionmodified"),
            "submissionpublished": obj.get("submissionpublished"),
            "submissiontitle": obj.get("submissiontitle"),
            "userid": obj.get("userid")
        }
        _obj = cls.model_construct(**data) if relaxed else cls.model_validate(data)
        return _obj





# coding: utf-8

"""
    Moodle Webservice API

    Auto-generated OpenAPI spec for Moodle's Webservice API.

    The version of the OpenAPI document: 5.0.3 (Build: 20251006)
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from poodle_async_full.models.core_webservice_get_site_info_response_advancedfeatures_inner import CoreWebserviceGetSiteInfoResponseAdvancedfeaturesInner
from poodle_async_full.models.core_webservice_get_site_info_response_functions_inner import CoreWebserviceGetSiteInfoResponseFunctionsInner
from typing import Optional, Set
from typing_extensions import Self

from poodle_async_full.configuration import settings

class CoreWebserviceGetSiteInfoResponse(BaseModel):
    """
    CoreWebserviceGetSiteInfoResponse
    """ # noqa: E501
    advancedfeatures: Optional[List[CoreWebserviceGetSiteInfoResponseAdvancedfeaturesInner]] = Field(default=None, description="Advanced features availability")
    downloadfiles: Optional[StrictInt] = Field(default=None, description="1 if users are allowed to download files, 0 if not")
    firstname: Optional[StrictStr] = Field(description="first name")
    fullname: Optional[StrictStr] = Field(description="user full name")
    functions: List[CoreWebserviceGetSiteInfoResponseFunctionsInner]
    lang: Optional[StrictStr] = Field(description="Current language.")
    lastname: Optional[StrictStr] = Field(description="last name")
    limitconcurrentlogins: Optional[StrictInt] = Field(default=None, description="Number of concurrent sessions allowed")
    mobilecssurl: Optional[StrictStr] = Field(default=None, description="Mobile custom CSS theme")
    policyagreed: Optional[StrictInt] = Field(default=None, description="Whether user accepted all the policies.")
    release: Optional[StrictStr] = Field(default=None, description="Moodle release number")
    sitecalendartype: Optional[StrictStr] = Field(default=None, description="Calendar type set in the site.")
    siteid: Optional[StrictInt] = Field(default=None, description="Site course ID")
    sitename: Optional[StrictStr] = Field(description="site name")
    siteurl: Optional[StrictStr] = Field(description="site url")
    theme: Optional[StrictStr] = Field(default=None, description="Current theme for the user.")
    uploadfiles: Optional[StrictInt] = Field(default=None, description="1 if users are allowed to upload files, 0 if not")
    usercalendartype: Optional[StrictStr] = Field(default=None, description="Calendar typed used by the user.")
    usercanmanageownfiles: Optional[StrictBool] = Field(default=None, description="true if the user can manage his own files")
    userhomepage: Optional[StrictInt] = Field(default=None, description="the default home page for the user: 0 for the site home, 1 for dashboard")
    userhomepageurl: Optional[StrictStr] = Field(default=None, description="The URL of default home page when userhomepage is 4 (HOMEPAGE_URL).")
    userid: Optional[StrictInt] = Field(description="user id")
    userissiteadmin: Optional[StrictBool] = Field(default=None, description="Whether the user is a site admin or not.")
    usermaxuploadfilesize: Optional[StrictInt] = Field(default=None, description="user max upload file size (bytes). -1 means the user can ignore the upload file size")
    username: Optional[StrictStr] = Field(description="username")
    userpictureurl: Optional[StrictStr] = Field(description="the user profile picture.                     Warning: this url is the public URL that only works when forcelogin is set to NO and guestaccess is set to YES.                     In order to retrieve user profile pictures independently of the Moodle config, replace \"pluginfile.php\" by                     \"webservice/pluginfile.php?token=WSTOKEN&file=\"                     Of course the user can only see profile picture depending                     on his/her permissions. Moreover it is recommended to use HTTPS too.")
    userprivateaccesskey: Optional[StrictStr] = Field(default=None, description="Private user access key for fetching files.")
    userquota: Optional[StrictInt] = Field(default=None, description="user quota (bytes). 0 means user can ignore the quota")
    usersessionscount: Optional[StrictInt] = Field(default=None, description="Number of active sessions for current user.                     Only returned when limitconcurrentlogins is used.")
    version: Optional[StrictStr] = Field(default=None, description="Moodle version number")
    __properties: ClassVar[List[str]] = ["advancedfeatures", "downloadfiles", "firstname", "fullname", "functions", "lang", "lastname", "limitconcurrentlogins", "mobilecssurl", "policyagreed", "release", "sitecalendartype", "siteid", "sitename", "siteurl", "theme", "uploadfiles", "usercalendartype", "usercanmanageownfiles", "userhomepage", "userhomepageurl", "userid", "userissiteadmin", "usermaxuploadfilesize", "username", "userpictureurl", "userprivateaccesskey", "userquota", "usersessionscount", "version"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CoreWebserviceGetSiteInfoResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in advancedfeatures (list)
        _items = []
        if self.advancedfeatures:
            for _item_advancedfeatures in self.advancedfeatures:
                if _item_advancedfeatures:
                    _items.append(_item_advancedfeatures.to_dict())
            _dict['advancedfeatures'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in functions (list)
        _items = []
        if self.functions:
            for _item_functions in self.functions:
                if _item_functions:
                    _items.append(_item_functions.to_dict())
            _dict['functions'] = _items
        # set to None if downloadfiles (nullable) is None
        # and model_fields_set contains the field
        if self.downloadfiles is None and "downloadfiles" in self.model_fields_set:
            _dict['downloadfiles'] = None

        # set to None if firstname (nullable) is None
        # and model_fields_set contains the field
        if self.firstname is None and "firstname" in self.model_fields_set:
            _dict['firstname'] = None

        # set to None if fullname (nullable) is None
        # and model_fields_set contains the field
        if self.fullname is None and "fullname" in self.model_fields_set:
            _dict['fullname'] = None

        # set to None if lang (nullable) is None
        # and model_fields_set contains the field
        if self.lang is None and "lang" in self.model_fields_set:
            _dict['lang'] = None

        # set to None if lastname (nullable) is None
        # and model_fields_set contains the field
        if self.lastname is None and "lastname" in self.model_fields_set:
            _dict['lastname'] = None

        # set to None if limitconcurrentlogins (nullable) is None
        # and model_fields_set contains the field
        if self.limitconcurrentlogins is None and "limitconcurrentlogins" in self.model_fields_set:
            _dict['limitconcurrentlogins'] = None

        # set to None if mobilecssurl (nullable) is None
        # and model_fields_set contains the field
        if self.mobilecssurl is None and "mobilecssurl" in self.model_fields_set:
            _dict['mobilecssurl'] = None

        # set to None if policyagreed (nullable) is None
        # and model_fields_set contains the field
        if self.policyagreed is None and "policyagreed" in self.model_fields_set:
            _dict['policyagreed'] = None

        # set to None if release (nullable) is None
        # and model_fields_set contains the field
        if self.release is None and "release" in self.model_fields_set:
            _dict['release'] = None

        # set to None if sitecalendartype (nullable) is None
        # and model_fields_set contains the field
        if self.sitecalendartype is None and "sitecalendartype" in self.model_fields_set:
            _dict['sitecalendartype'] = None

        # set to None if siteid (nullable) is None
        # and model_fields_set contains the field
        if self.siteid is None and "siteid" in self.model_fields_set:
            _dict['siteid'] = None

        # set to None if sitename (nullable) is None
        # and model_fields_set contains the field
        if self.sitename is None and "sitename" in self.model_fields_set:
            _dict['sitename'] = None

        # set to None if siteurl (nullable) is None
        # and model_fields_set contains the field
        if self.siteurl is None and "siteurl" in self.model_fields_set:
            _dict['siteurl'] = None

        # set to None if theme (nullable) is None
        # and model_fields_set contains the field
        if self.theme is None and "theme" in self.model_fields_set:
            _dict['theme'] = None

        # set to None if uploadfiles (nullable) is None
        # and model_fields_set contains the field
        if self.uploadfiles is None and "uploadfiles" in self.model_fields_set:
            _dict['uploadfiles'] = None

        # set to None if usercalendartype (nullable) is None
        # and model_fields_set contains the field
        if self.usercalendartype is None and "usercalendartype" in self.model_fields_set:
            _dict['usercalendartype'] = None

        # set to None if usercanmanageownfiles (nullable) is None
        # and model_fields_set contains the field
        if self.usercanmanageownfiles is None and "usercanmanageownfiles" in self.model_fields_set:
            _dict['usercanmanageownfiles'] = None

        # set to None if userhomepage (nullable) is None
        # and model_fields_set contains the field
        if self.userhomepage is None and "userhomepage" in self.model_fields_set:
            _dict['userhomepage'] = None

        # set to None if userhomepageurl (nullable) is None
        # and model_fields_set contains the field
        if self.userhomepageurl is None and "userhomepageurl" in self.model_fields_set:
            _dict['userhomepageurl'] = None

        # set to None if userid (nullable) is None
        # and model_fields_set contains the field
        if self.userid is None and "userid" in self.model_fields_set:
            _dict['userid'] = None

        # set to None if userissiteadmin (nullable) is None
        # and model_fields_set contains the field
        if self.userissiteadmin is None and "userissiteadmin" in self.model_fields_set:
            _dict['userissiteadmin'] = None

        # set to None if usermaxuploadfilesize (nullable) is None
        # and model_fields_set contains the field
        if self.usermaxuploadfilesize is None and "usermaxuploadfilesize" in self.model_fields_set:
            _dict['usermaxuploadfilesize'] = None

        # set to None if username (nullable) is None
        # and model_fields_set contains the field
        if self.username is None and "username" in self.model_fields_set:
            _dict['username'] = None

        # set to None if userpictureurl (nullable) is None
        # and model_fields_set contains the field
        if self.userpictureurl is None and "userpictureurl" in self.model_fields_set:
            _dict['userpictureurl'] = None

        # set to None if userprivateaccesskey (nullable) is None
        # and model_fields_set contains the field
        if self.userprivateaccesskey is None and "userprivateaccesskey" in self.model_fields_set:
            _dict['userprivateaccesskey'] = None

        # set to None if userquota (nullable) is None
        # and model_fields_set contains the field
        if self.userquota is None and "userquota" in self.model_fields_set:
            _dict['userquota'] = None

        # set to None if usersessionscount (nullable) is None
        # and model_fields_set contains the field
        if self.usersessionscount is None and "usersessionscount" in self.model_fields_set:
            _dict['usersessionscount'] = None

        # set to None if version (nullable) is None
        # and model_fields_set contains the field
        if self.version is None and "version" in self.model_fields_set:
            _dict['version'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CoreWebserviceGetSiteInfoResponse from a dict"""
        if obj is None:
            return None

        relaxed = settings.relaxe_all_models or "CoreWebserviceGetSiteInfoResponse" in settings.relaxed_models

        if not isinstance(obj, dict):
            return cls.model_construct(**obj) if relaxed else cls.model_validate(obj)

        data = {
            "advancedfeatures": [CoreWebserviceGetSiteInfoResponseAdvancedfeaturesInner.from_dict(_item) for _item in obj["advancedfeatures"]] if obj.get("advancedfeatures") is not None else None,
            "downloadfiles": obj.get("downloadfiles"),
            "firstname": obj.get("firstname"),
            "fullname": obj.get("fullname"),
            "functions": [CoreWebserviceGetSiteInfoResponseFunctionsInner.from_dict(_item) for _item in obj["functions"]] if obj.get("functions") is not None else None,
            "lang": obj.get("lang"),
            "lastname": obj.get("lastname"),
            "limitconcurrentlogins": obj.get("limitconcurrentlogins"),
            "mobilecssurl": obj.get("mobilecssurl"),
            "policyagreed": obj.get("policyagreed"),
            "release": obj.get("release"),
            "sitecalendartype": obj.get("sitecalendartype"),
            "siteid": obj.get("siteid"),
            "sitename": obj.get("sitename"),
            "siteurl": obj.get("siteurl"),
            "theme": obj.get("theme"),
            "uploadfiles": obj.get("uploadfiles"),
            "usercalendartype": obj.get("usercalendartype"),
            "usercanmanageownfiles": obj.get("usercanmanageownfiles"),
            "userhomepage": obj.get("userhomepage"),
            "userhomepageurl": obj.get("userhomepageurl"),
            "userid": obj.get("userid"),
            "userissiteadmin": obj.get("userissiteadmin"),
            "usermaxuploadfilesize": obj.get("usermaxuploadfilesize"),
            "username": obj.get("username"),
            "userpictureurl": obj.get("userpictureurl"),
            "userprivateaccesskey": obj.get("userprivateaccesskey"),
            "userquota": obj.get("userquota"),
            "usersessionscount": obj.get("usersessionscount"),
            "version": obj.get("version")
        }
        _obj = cls.model_construct(**data) if relaxed else cls.model_validate(data)
        return _obj





# coding: utf-8

"""
    Moodle Webservice API

    Auto-generated OpenAPI spec for Moodle's Webservice API.

    The version of the OpenAPI document: 5.0.3 (Build: 20251006)
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from poodle_async_full.models.core_calendar_get_calendar_day_view_response_events_inner import CoreCalendarGetCalendarDayViewResponseEventsInner
from typing import Optional, Set
from typing_extensions import Self

from poodle_async_full.configuration import settings

class CoreCalendarGetCalendarMonthlyViewResponseWeeksInnerDaysInner(BaseModel):
    """
    CoreCalendarGetCalendarMonthlyViewResponseWeeksInnerDaysInner
    """ # noqa: E501
    calendareventtypes: List[StrictStr] = Field(description="calendareventtypes")
    daytitle: StrictStr = Field(description="daytitle")
    events: List[CoreCalendarGetCalendarDayViewResponseEventsInner] = Field(description="events")
    hasevents: StrictBool = Field(description="hasevents")
    haslastdayofevent: StrictBool = Field(description="haslastdayofevent")
    hours: StrictInt = Field(description="hours")
    istoday: StrictBool = Field(description="istoday")
    isweekend: StrictBool = Field(description="isweekend")
    mday: StrictInt = Field(description="mday")
    minutes: StrictInt = Field(description="minutes")
    neweventtimestamp: StrictInt = Field(description="neweventtimestamp")
    nextperiod: StrictInt = Field(description="nextperiod")
    popovertitle: StrictStr = Field(description="popovertitle")
    previousperiod: StrictInt = Field(description="previousperiod")
    seconds: StrictInt = Field(description="seconds")
    timestamp: StrictInt = Field(description="timestamp")
    viewdaylink: Optional[StrictStr] = Field(default='', description="viewdaylink")
    viewdaylinktitle: Optional[StrictStr] = Field(default='', description="viewdaylinktitle")
    wday: StrictInt = Field(description="wday")
    yday: StrictInt = Field(description="yday")
    year: StrictInt = Field(description="year")
    __properties: ClassVar[List[str]] = ["calendareventtypes", "daytitle", "events", "hasevents", "haslastdayofevent", "hours", "istoday", "isweekend", "mday", "minutes", "neweventtimestamp", "nextperiod", "popovertitle", "previousperiod", "seconds", "timestamp", "viewdaylink", "viewdaylinktitle", "wday", "yday", "year"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CoreCalendarGetCalendarMonthlyViewResponseWeeksInnerDaysInner from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in events (list)
        _items = []
        if self.events:
            for _item_events in self.events:
                if _item_events:
                    _items.append(_item_events.to_dict())
            _dict['events'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CoreCalendarGetCalendarMonthlyViewResponseWeeksInnerDaysInner from a dict"""
        if obj is None:
            return None

        relaxed = settings.relaxe_all_models or "CoreCalendarGetCalendarMonthlyViewResponseWeeksInnerDaysInner" in settings.relaxed_models

        if not isinstance(obj, dict):
            return cls.model_construct(**obj) if relaxed else cls.model_validate(obj)

        data = {
            "calendareventtypes": obj.get("calendareventtypes"),
            "daytitle": obj.get("daytitle") if obj.get("daytitle") is not None else '',
            "events": [CoreCalendarGetCalendarDayViewResponseEventsInner.from_dict(_item) for _item in obj["events"]] if obj.get("events") is not None else None,
            "hasevents": obj.get("hasevents") if obj.get("hasevents") is not None else False,
            "haslastdayofevent": obj.get("haslastdayofevent") if obj.get("haslastdayofevent") is not None else False,
            "hours": obj.get("hours") if obj.get("hours") is not None else 0,
            "istoday": obj.get("istoday") if obj.get("istoday") is not None else False,
            "isweekend": obj.get("isweekend") if obj.get("isweekend") is not None else False,
            "mday": obj.get("mday") if obj.get("mday") is not None else 0,
            "minutes": obj.get("minutes") if obj.get("minutes") is not None else 0,
            "neweventtimestamp": obj.get("neweventtimestamp") if obj.get("neweventtimestamp") is not None else 0,
            "nextperiod": obj.get("nextperiod") if obj.get("nextperiod") is not None else 0,
            "popovertitle": obj.get("popovertitle") if obj.get("popovertitle") is not None else '',
            "previousperiod": obj.get("previousperiod") if obj.get("previousperiod") is not None else 0,
            "seconds": obj.get("seconds") if obj.get("seconds") is not None else 0,
            "timestamp": obj.get("timestamp") if obj.get("timestamp") is not None else 0,
            "viewdaylink": obj.get("viewdaylink") if obj.get("viewdaylink") is not None else '',
            "viewdaylinktitle": obj.get("viewdaylinktitle") if obj.get("viewdaylinktitle") is not None else '',
            "wday": obj.get("wday") if obj.get("wday") is not None else 0,
            "yday": obj.get("yday") if obj.get("yday") is not None else 0,
            "year": obj.get("year") if obj.get("year") is not None else 0
        }
        _obj = cls.model_construct(**data) if relaxed else cls.model_validate(data)
        return _obj





# coding: utf-8

"""
    Moodle Webservice API

    Auto-generated OpenAPI spec for Moodle's Webservice API.

    The version of the OpenAPI document: 5.0.3 (Build: 20251006)
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from poodle_async_full.models.core_competency_read_user_evidence_response_files_inner import CoreCompetencyReadUserEvidenceResponseFilesInner
from poodle_async_full.models.tool_lp_data_for_user_evidence_list_page_response_evidence_inner_usercompetencies_inner import ToolLpDataForUserEvidenceListPageResponseEvidenceInnerUsercompetenciesInner
from typing import Optional, Set
from typing_extensions import Self

from poodle_async_full.configuration import settings

class ToolLpDataForUserEvidenceListPageResponseEvidenceInner(BaseModel):
    """
    ToolLpDataForUserEvidenceListPageResponseEvidenceInner
    """ # noqa: E501
    canmanage: StrictBool = Field(description="canmanage")
    competencycount: StrictInt = Field(description="competencycount")
    description: StrictStr = Field(description="description")
    descriptionformat: Optional[StrictInt] = Field(default=1, description="description format (1 = HTML, 0 = MOODLE, 2 = PLAIN, or 4 = MARKDOWN)")
    filecount: StrictInt = Field(description="filecount")
    files: List[CoreCompetencyReadUserEvidenceResponseFilesInner] = Field(description="files")
    hasurlorfiles: StrictBool = Field(description="hasurlorfiles")
    id: StrictInt = Field(description="id")
    name: StrictStr = Field(description="name")
    timecreated: StrictInt = Field(description="timecreated")
    timemodified: StrictInt = Field(description="timemodified")
    url: StrictStr = Field(description="url")
    urlshort: StrictStr = Field(description="urlshort")
    usercompetencies: Optional[List[ToolLpDataForUserEvidenceListPageResponseEvidenceInnerUsercompetenciesInner]] = Field(default=None, description="usercompetencies")
    userhasplan: StrictBool = Field(description="userhasplan")
    userid: StrictInt = Field(description="userid")
    usermodified: StrictInt = Field(description="usermodified")
    __properties: ClassVar[List[str]] = ["canmanage", "competencycount", "description", "descriptionformat", "filecount", "files", "hasurlorfiles", "id", "name", "timecreated", "timemodified", "url", "urlshort", "usercompetencies", "userhasplan", "userid", "usermodified"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ToolLpDataForUserEvidenceListPageResponseEvidenceInner from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in files (list)
        _items = []
        if self.files:
            for _item_files in self.files:
                if _item_files:
                    _items.append(_item_files.to_dict())
            _dict['files'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in usercompetencies (list)
        _items = []
        if self.usercompetencies:
            for _item_usercompetencies in self.usercompetencies:
                if _item_usercompetencies:
                    _items.append(_item_usercompetencies.to_dict())
            _dict['usercompetencies'] = _items
        # set to None if descriptionformat (nullable) is None
        # and model_fields_set contains the field
        if self.descriptionformat is None and "descriptionformat" in self.model_fields_set:
            _dict['descriptionformat'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ToolLpDataForUserEvidenceListPageResponseEvidenceInner from a dict"""
        if obj is None:
            return None

        relaxed = settings.relaxe_all_models or "ToolLpDataForUserEvidenceListPageResponseEvidenceInner" in settings.relaxed_models

        if not isinstance(obj, dict):
            return cls.model_construct(**obj) if relaxed else cls.model_validate(obj)

        data = {
            "canmanage": obj.get("canmanage") if obj.get("canmanage") is not None else False,
            "competencycount": obj.get("competencycount") if obj.get("competencycount") is not None else 0,
            "description": obj.get("description") if obj.get("description") is not None else '',
            "descriptionformat": obj.get("descriptionformat") if obj.get("descriptionformat") is not None else 1,
            "filecount": obj.get("filecount") if obj.get("filecount") is not None else 0,
            "files": [CoreCompetencyReadUserEvidenceResponseFilesInner.from_dict(_item) for _item in obj["files"]] if obj.get("files") is not None else None,
            "hasurlorfiles": obj.get("hasurlorfiles") if obj.get("hasurlorfiles") is not None else False,
            "id": obj.get("id") if obj.get("id") is not None else 0,
            "name": obj.get("name") if obj.get("name") is not None else '',
            "timecreated": obj.get("timecreated") if obj.get("timecreated") is not None else 0,
            "timemodified": obj.get("timemodified") if obj.get("timemodified") is not None else 0,
            "url": obj.get("url") if obj.get("url") is not None else '',
            "urlshort": obj.get("urlshort") if obj.get("urlshort") is not None else '',
            "usercompetencies": [ToolLpDataForUserEvidenceListPageResponseEvidenceInnerUsercompetenciesInner.from_dict(_item) for _item in obj["usercompetencies"]] if obj.get("usercompetencies") is not None else None,
            "userhasplan": obj.get("userhasplan") if obj.get("userhasplan") is not None else False,
            "userid": obj.get("userid") if obj.get("userid") is not None else 0,
            "usermodified": obj.get("usermodified") if obj.get("usermodified") is not None else 0
        }
        _obj = cls.model_construct(**data) if relaxed else cls.model_validate(data)
        return _obj





# coding: utf-8

"""
    Moodle Webservice API

    Auto-generated OpenAPI spec for Moodle's Webservice API.

    The version of the OpenAPI document: 5.0.3 (Build: 20251006)
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictFloat, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from typing import Optional, Set
from typing_extensions import Self

from poodle_async_full.configuration import settings

class GradereportUserGetGradeItemsResponseUsergradesInnerGradeitemsInner(BaseModel):
    """
    Grade items
    """ # noqa: E501
    averageformatted: Optional[StrictStr] = Field(default=None, description="Grade average")
    categoryid: Optional[StrictInt] = Field(description="Grade item category id")
    cmid: Optional[StrictInt] = Field(default=None, description="Course module id (if type mod)")
    feedback: Optional[StrictStr] = Field(default=None, description="Grade feedback")
    feedbackformat: Optional[StrictInt] = Field(default=None, description="feedback format (1 = HTML, 0 = MOODLE, 2 = PLAIN, or 4 = MARKDOWN)")
    gradedategraded: Optional[StrictInt] = Field(default=None, description="Grade graded date")
    gradedatesubmitted: Optional[StrictInt] = Field(default=None, description="Grade submit date")
    gradeformatted: Optional[StrictStr] = Field(default=None, description="The grade formatted")
    gradehiddenbydate: Optional[StrictBool] = Field(default=None, description="Grade hidden by date?")
    gradeishidden: Optional[StrictBool] = Field(default=None, description="Grade is hidden?")
    gradeislocked: Optional[StrictBool] = Field(default=None, description="Grade is locked?")
    gradeisoverridden: Optional[StrictBool] = Field(default=None, description="Grade overridden?")
    grademax: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="Grade max")
    grademin: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="Grade min")
    gradeneedsupdate: Optional[StrictBool] = Field(default=None, description="Grade needs update?")
    graderaw: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="Grade raw")
    id: Optional[StrictInt] = Field(description="Grade item id")
    idnumber: Optional[StrictStr] = Field(description="Grade item idnumber")
    iteminstance: Optional[StrictInt] = Field(description="Grade item instance")
    itemmodule: Optional[StrictStr] = Field(description="Grade item module")
    itemname: Optional[StrictStr] = Field(description="Grade item name")
    itemnumber: Optional[StrictInt] = Field(description="Grade item item number")
    itemtype: Optional[StrictStr] = Field(description="Grade item type")
    lettergradeformatted: Optional[StrictStr] = Field(default=None, description="Letter grade")
    locked: Optional[StrictBool] = Field(default=None, description="Grade item for user locked?")
    numusers: Optional[StrictInt] = Field(default=None, description="Num users in course")
    outcomeid: Optional[StrictInt] = Field(description="Outcome id")
    percentageformatted: Optional[StrictStr] = Field(default=None, description="Percentage")
    rangeformatted: Optional[StrictStr] = Field(default=None, description="Range formatted")
    rank: Optional[StrictInt] = Field(default=None, description="Rank in the course")
    scaleid: Optional[StrictInt] = Field(description="Scale id")
    status: Optional[StrictStr] = Field(default=None, description="Status")
    weightformatted: Optional[StrictStr] = Field(default=None, description="Weight")
    weightraw: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="Weight raw")
    __properties: ClassVar[List[str]] = ["averageformatted", "categoryid", "cmid", "feedback", "feedbackformat", "gradedategraded", "gradedatesubmitted", "gradeformatted", "gradehiddenbydate", "gradeishidden", "gradeislocked", "gradeisoverridden", "grademax", "grademin", "gradeneedsupdate", "graderaw", "id", "idnumber", "iteminstance", "itemmodule", "itemname", "itemnumber", "itemtype", "lettergradeformatted", "locked", "numusers", "outcomeid", "percentageformatted", "rangeformatted", "rank", "scaleid", "status", "weightformatted", "weightraw"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of GradereportUserGetGradeItemsResponseUsergradesInnerGradeitemsInner from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if averageformatted (nullable) is None
        # and model_fields_set contains the field
        if self.averageformatted is None and "averageformatted" in self.model_fields_set:
            _dict['averageformatted'] = None

        # set to None if categoryid (nullable) is None
        # and model_fields_set contains the field
        if self.categoryid is None and "categoryid" in self.model_fields_set:
            _dict['categoryid'] = None

        # set to None if cmid (nullable) is None
        # and model_fields_set contains the field
        if self.cmid is None and "cmid" in self.model_fields_set:
            _dict['cmid'] = None

        # set to None if feedback (nullable) is None
        # and model_fields_set contains the field
        if self.feedback is None and "feedback" in self.model_fields_set:
            _dict['feedback'] = None

        # set to None if feedbackformat (nullable) is None
        # and model_fields_set contains the field
        if self.feedbackformat is None and "feedbackformat" in self.model_fields_set:
            _dict['feedbackformat'] = None

        # set to None if gradedategraded (nullable) is None
        # and model_fields_set contains the field
        if self.gradedategraded is None and "gradedategraded" in self.model_fields_set:
            _dict['gradedategraded'] = None

        # set to None if gradedatesubmitted (nullable) is None
        # and model_fields_set contains the field
        if self.gradedatesubmitted is None and "gradedatesubmitted" in self.model_fields_set:
            _dict['gradedatesubmitted'] = None

        # set to None if gradeformatted (nullable) is None
        # and model_fields_set contains the field
        if self.gradeformatted is None and "gradeformatted" in self.model_fields_set:
            _dict['gradeformatted'] = None

        # set to None if gradehiddenbydate (nullable) is None
        # and model_fields_set contains the field
        if self.gradehiddenbydate is None and "gradehiddenbydate" in self.model_fields_set:
            _dict['gradehiddenbydate'] = None

        # set to None if gradeishidden (nullable) is None
        # and model_fields_set contains the field
        if self.gradeishidden is None and "gradeishidden" in self.model_fields_set:
            _dict['gradeishidden'] = None

        # set to None if gradeislocked (nullable) is None
        # and model_fields_set contains the field
        if self.gradeislocked is None and "gradeislocked" in self.model_fields_set:
            _dict['gradeislocked'] = None

        # set to None if gradeisoverridden (nullable) is None
        # and model_fields_set contains the field
        if self.gradeisoverridden is None and "gradeisoverridden" in self.model_fields_set:
            _dict['gradeisoverridden'] = None

        # set to None if grademax (nullable) is None
        # and model_fields_set contains the field
        if self.grademax is None and "grademax" in self.model_fields_set:
            _dict['grademax'] = None

        # set to None if grademin (nullable) is None
        # and model_fields_set contains the field
        if self.grademin is None and "grademin" in self.model_fields_set:
            _dict['grademin'] = None

        # set to None if gradeneedsupdate (nullable) is None
        # and model_fields_set contains the field
        if self.gradeneedsupdate is None and "gradeneedsupdate" in self.model_fields_set:
            _dict['gradeneedsupdate'] = None

        # set to None if graderaw (nullable) is None
        # and model_fields_set contains the field
        if self.graderaw is None and "graderaw" in self.model_fields_set:
            _dict['graderaw'] = None

        # set to None if id (nullable) is None
        # and model_fields_set contains the field
        if self.id is None and "id" in self.model_fields_set:
            _dict['id'] = None

        # set to None if idnumber (nullable) is None
        # and model_fields_set contains the field
        if self.idnumber is None and "idnumber" in self.model_fields_set:
            _dict['idnumber'] = None

        # set to None if iteminstance (nullable) is None
        # and model_fields_set contains the field
        if self.iteminstance is None and "iteminstance" in self.model_fields_set:
            _dict['iteminstance'] = None

        # set to None if itemmodule (nullable) is None
        # and model_fields_set contains the field
        if self.itemmodule is None and "itemmodule" in self.model_fields_set:
            _dict['itemmodule'] = None

        # set to None if itemname (nullable) is None
        # and model_fields_set contains the field
        if self.itemname is None and "itemname" in self.model_fields_set:
            _dict['itemname'] = None

        # set to None if itemnumber (nullable) is None
        # and model_fields_set contains the field
        if self.itemnumber is None and "itemnumber" in self.model_fields_set:
            _dict['itemnumber'] = None

        # set to None if itemtype (nullable) is None
        # and model_fields_set contains the field
        if self.itemtype is None and "itemtype" in self.model_fields_set:
            _dict['itemtype'] = None

        # set to None if lettergradeformatted (nullable) is None
        # and model_fields_set contains the field
        if self.lettergradeformatted is None and "lettergradeformatted" in self.model_fields_set:
            _dict['lettergradeformatted'] = None

        # set to None if locked (nullable) is None
        # and model_fields_set contains the field
        if self.locked is None and "locked" in self.model_fields_set:
            _dict['locked'] = None

        # set to None if numusers (nullable) is None
        # and model_fields_set contains the field
        if self.numusers is None and "numusers" in self.model_fields_set:
            _dict['numusers'] = None

        # set to None if outcomeid (nullable) is None
        # and model_fields_set contains the field
        if self.outcomeid is None and "outcomeid" in self.model_fields_set:
            _dict['outcomeid'] = None

        # set to None if percentageformatted (nullable) is None
        # and model_fields_set contains the field
        if self.percentageformatted is None and "percentageformatted" in self.model_fields_set:
            _dict['percentageformatted'] = None

        # set to None if rangeformatted (nullable) is None
        # and model_fields_set contains the field
        if self.rangeformatted is None and "rangeformatted" in self.model_fields_set:
            _dict['rangeformatted'] = None

        # set to None if rank (nullable) is None
        # and model_fields_set contains the field
        if self.rank is None and "rank" in self.model_fields_set:
            _dict['rank'] = None

        # set to None if scaleid (nullable) is None
        # and model_fields_set contains the field
        if self.scaleid is None and "scaleid" in self.model_fields_set:
            _dict['scaleid'] = None

        # set to None if status (nullable) is None
        # and model_fields_set contains the field
        if self.status is None and "status" in self.model_fields_set:
            _dict['status'] = None

        # set to None if weightformatted (nullable) is None
        # and model_fields_set contains the field
        if self.weightformatted is None and "weightformatted" in self.model_fields_set:
            _dict['weightformatted'] = None

        # set to None if weightraw (nullable) is None
        # and model_fields_set contains the field
        if self.weightraw is None and "weightraw" in self.model_fields_set:
            _dict['weightraw'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of GradereportUserGetGradeItemsResponseUsergradesInnerGradeitemsInner from a dict"""
        if obj is None:
            return None

        relaxed = settings.relaxe_all_models or "GradereportUserGetGradeItemsResponseUsergradesInnerGradeitemsInner" in settings.relaxed_models

        if not isinstance(obj, dict):
            return cls.model_construct(**obj) if relaxed else cls.model_validate(obj)

        data = {
            "averageformatted": obj.get("averageformatted"),
            "categoryid": obj.get("categoryid"),
            "cmid": obj.get("cmid"),
            "feedback": obj.get("feedback"),
            "feedbackformat": obj.get("feedbackformat"),
            "gradedategraded": obj.get("gradedategraded"),
            "gradedatesubmitted": obj.get("gradedatesubmitted"),
            "gradeformatted": obj.get("gradeformatted"),
            "gradehiddenbydate": obj.get("gradehiddenbydate"),
            "gradeishidden": obj.get("gradeishidden"),
            "gradeislocked": obj.get("gradeislocked"),
            "gradeisoverridden": obj.get("gradeisoverridden"),
            "grademax": obj.get("grademax"),
            "grademin": obj.get("grademin"),
            "gradeneedsupdate": obj.get("gradeneedsupdate"),
            "graderaw": obj.get("graderaw"),
            "id": obj.get("id"),
            "idnumber": obj.get("idnumber"),
            "iteminstance": obj.get("iteminstance"),
            "itemmodule": obj.get("itemmodule"),
            "itemname": obj.get("itemname"),
            "itemnumber": obj.get("itemnumber"),
            "itemtype": obj.get("itemtype"),
            "lettergradeformatted": obj.get("lettergradeformatted"),
            "locked": obj.get("locked"),
            "numusers": obj.get("numusers"),
            "outcomeid": obj.get("outcomeid"),
            "percentageformatted": obj.get("percentageformatted"),
            "rangeformatted": obj.get("rangeformatted"),
            "rank": obj.get("rank"),
            "scaleid": obj.get("scaleid"),
            "status": obj.get("status"),
            "weightformatted": obj.get("weightformatted"),
            "weightraw": obj.get("weightraw")
        }
        _obj = cls.model_construct(**data) if relaxed else cls.model_validate(data)
        return _obj


